@@ -66,7 +66,8 @@ with 32px folder icon</source>
         <location filename="../../KvantumPreviewBase.ui" line="224"/>
         <source>Default
 push button</source>
-        <translation>Defaŭlta prembutono</translation>
+        <translation>Defaŭlta
+prembutono</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="266"/>
@@ -499,9 +500,9 @@ markbutono</translation>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="2315"/>
         <location filename="../../KvantumPreviewBase.ui" line="2367"/>
-        <location filename="../../KvantumPreviewBase.ui" line="2658"/>
-        <location filename="../../KvantumPreviewBase.ui" line="2735"/>
-        <location filename="../../KvantumPreviewBase.ui" line="2783"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2661"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2738"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2786"/>
         <source>Tab 1</source>
         <translation>Folio 1</translation>
     </message>
@@ -513,9 +514,9 @@ markbutono</translation>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="2333"/>
         <location filename="../../KvantumPreviewBase.ui" line="2381"/>
-        <location filename="../../KvantumPreviewBase.ui" line="2676"/>
-        <location filename="../../KvantumPreviewBase.ui" line="2749"/>
-        <location filename="../../KvantumPreviewBase.ui" line="2797"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2679"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2752"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2800"/>
         <source>Tab 2</source>
         <translation>Folio 2</translation>
     </message>
@@ -528,8 +529,8 @@ markbutono</translation>
         <location filename="../../KvantumPreviewBase.ui" line="2373"/>
         <location filename="../../KvantumPreviewBase.ui" line="2566"/>
         <location filename="../../KvantumPreviewBase.ui" line="2621"/>
-        <location filename="../../KvantumPreviewBase.ui" line="2741"/>
-        <location filename="../../KvantumPreviewBase.ui" line="2789"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2744"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2792"/>
         <source>Page 1</source>
         <translation>Paĝo 1</translation>
     </message>
@@ -537,9 +538,9 @@ markbutono</translation>
         <location filename="../../KvantumPreviewBase.ui" line="2387"/>
         <location filename="../../KvantumPreviewBase.ui" line="2594"/>
         <location filename="../../KvantumPreviewBase.ui" line="2634"/>
-        <location filename="../../KvantumPreviewBase.ui" line="2682"/>
-        <location filename="../../KvantumPreviewBase.ui" line="2755"/>
-        <location filename="../../KvantumPreviewBase.ui" line="2803"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2685"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2758"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2806"/>
         <source>Page 2</source>
         <translation>Paĝo 2</translation>
     </message>
@@ -574,97 +575,97 @@ markbutono</translation>
         <translation>Ilujo</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2664"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2667"/>
         <source>Document mode</source>
         <translation>Dokumenta moduso</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2702"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2705"/>
         <source>Box frame</source>
         <translation>Skatolkadro</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2832"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2835"/>
         <source>&amp;File</source>
         <translation>&amp;Dosiero</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2836"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2839"/>
         <source>&amp;Submenu</source>
         <translation>&amp;Submenuo</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2856"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2859"/>
         <source>toolBar</source>
         <translation>Ilbreto</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2873"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2879"/>
         <source>toolBar_2</source>
         <translation>Ilbreto_2</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2892"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2901"/>
         <source>&amp;Quit</source>
         <translation>&amp;Eliri</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2895"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2904"/>
         <source>Quit</source>
         <translation>Eliri</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2898"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2907"/>
         <source>Ctrl+Q</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2906"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2915"/>
         <source>&amp;Checkbox</source>
         <translation>&amp;Markbutono</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2919"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2928"/>
         <source>Toggle Layout</source>
         <translation>Inversi la aranĝon</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2922"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2931"/>
         <source>Toggle layout direction</source>
         <translation>Inversi la direkton de la aranĝo</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2934"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2943"/>
         <source>&amp;Doc Mode</source>
         <translation>&amp;Dokumenta moduso</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2937"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2946"/>
         <source>Show tabs in the document mode</source>
-        <translation>Montro la foliojn laŭ la dokumenta moduso</translation>
+        <translation>Montru la foliojn laŭ la dokumenta moduso</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2949"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2958"/>
         <source>Menu Button</source>
         <translation>Menubutono</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2952"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2961"/>
         <source>Hold pressed to show a menu</source>
         <translation>Tenu premante por montri menuon</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2963"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2972"/>
         <source>C&amp;heckbox</source>
         <translation>M&amp;arkbutono</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2971"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2980"/>
         <source>&amp;Radio button</source>
         <translation>&amp;Radiobutono</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2979"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2988"/>
         <source>Radio &amp;button</source>
         <translation>Radi&amp;obutono</translation>
     </message>
