@@ -6,12 +6,12 @@
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="14"/>
         <source>Kvantum Preview</source>
-        <translation type="unfinished"></translation>
+        <translation>Kvantumin esikatselu</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="29"/>
         <source>Push buttons</source>
-        <translation type="unfinished"></translation>
+        <translation>Painikkeet</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="77"/>
@@ -24,96 +24,112 @@ height
 greater
 than
 width</source>
-        <translation type="unfinished"></translation>
+        <translation>Vaihda
+työnnä
+painiketta
+
+jossa on
+korkeus
+suurempi
+kuin
+leveys</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="95"/>
         <location filename="../../KvantumPreviewBase.ui" line="105"/>
         <source>Simple push button</source>
-        <translation type="unfinished"></translation>
+        <translation>Yksinkertainen painike</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="112"/>
         <location filename="../../KvantumPreviewBase.ui" line="128"/>
         <source>Toggle push button</source>
-        <translation type="unfinished"></translation>
+        <translation>Vaihda painike</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="141"/>
         <location filename="../../KvantumPreviewBase.ui" line="152"/>
         <source>Multi-line
  push button</source>
-        <translation type="unfinished"></translation>
+        <translation>Monirivinen
+painike</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="160"/>
         <location filename="../../KvantumPreviewBase.ui" line="180"/>
         <source>Push button
 with 32px folder icon</source>
-        <translation type="unfinished"></translation>
+        <translation>Painike 32px
+   kansio kuvake</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="210"/>
         <location filename="../../KvantumPreviewBase.ui" line="224"/>
         <source>Default
 push button</source>
-        <translation type="unfinished"></translation>
+        <translation>Oletus
+painike</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="266"/>
         <source>Flat buttons</source>
-        <translation type="unfinished"></translation>
+        <translation>Litteät painikkeet</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="279"/>
         <source>Button Box</source>
-        <translation type="unfinished"></translation>
+        <translation>Painike ruutu</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="361"/>
         <source>Tool buttons</source>
-        <translation type="unfinished"></translation>
+        <translation>Työkalu painikkeet</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="369"/>
         <location filename="../../KvantumPreviewBase.ui" line="446"/>
         <source>Simple toolbutton</source>
-        <translation type="unfinished"></translation>
+        <translation>Perus työkalupainike</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="453"/>
         <location filename="../../KvantumPreviewBase.ui" line="464"/>
         <source>Multi-line
 toolbutton</source>
-        <translation type="unfinished"></translation>
+        <translation>Monirivinen
+työkalupainike</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="472"/>
         <location filename="../../KvantumPreviewBase.ui" line="495"/>
         <source>Toggle toolbutton
 with an arrow</source>
-        <translation type="unfinished"></translation>
+        <translation>Vaihda työkalupainiketta,
+jossa on nuoli</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="560"/>
         <location filename="../../KvantumPreviewBase.ui" line="584"/>
         <source>Toolbutton with 32px SVG icon
 and text below</source>
-        <translation type="unfinished"></translation>
+        <translation>Työkalupainike, jossa on 32px SVG-
+kuvake ja alla oleva teksti</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="605"/>
         <location filename="../../KvantumPreviewBase.ui" line="626"/>
         <source>Toolbutton with text below
 and arrow</source>
-        <translation type="unfinished"></translation>
+        <translation>Työkalupainike, jonka alla
+on tekstiä ja nuoli</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="644"/>
         <location filename="../../KvantumPreviewBase.ui" line="665"/>
         <source>Toolbutton with icon at the side
 and arrow</source>
-        <translation type="unfinished"></translation>
+        <translation>Työkalupainike ja kuvake
+sivussa ja nuoli</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="683"/>
@@ -121,14 +137,17 @@ and arrow</source>
         <source>Toggle toolbutton with icon,
 ordinary arrow
 and dropdown menu arrow</source>
-        <translation type="unfinished"></translation>
+        <translation>Vaihda työkalupainiketta, jossa
+on kuvake, tavallinen nuoli
+ja avattava valikon nuoli</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="515"/>
         <location filename="../../KvantumPreviewBase.ui" line="539"/>
         <source>Toolbutton with 32px PNG icon
 beside text</source>
-        <translation type="unfinished"></translation>
+        <translation>Työkalupainike ja 32px PNG-
+kuvake tekstin vieressä</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="402"/>
@@ -141,66 +160,75 @@ height
 greater
 than
 width</source>
-        <translation type="unfinished"></translation>
+        <translation>Vaihda
+työkalu
+painiketta
+
+jossa on
+korkeus
+suurempi
+kuin
+leveys</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="791"/>
         <source>Auto-raise</source>
-        <translation type="unfinished"></translation>
+        <translation>Automaattinen korotus</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="812"/>
         <source>Radio/Check buttons</source>
-        <translation type="unfinished"></translation>
+        <translation>Valinta/rasti-painikkeet</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="833"/>
         <location filename="../../KvantumPreviewBase.ui" line="846"/>
         <source>Simple radio button</source>
-        <translation type="unfinished"></translation>
+        <translation>Perus valintapainike</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="856"/>
         <location filename="../../KvantumPreviewBase.ui" line="867"/>
         <source>Multi-line
 radio button</source>
-        <translation type="unfinished"></translation>
+        <translation>Monirivinen
+valintapainike</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="878"/>
         <location filename="../../KvantumPreviewBase.ui" line="904"/>
         <source>Radio button with 32px SVG icon</source>
-        <translation type="unfinished"></translation>
+        <translation>Valintapainike, 32px SVG -kuvakeella</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="927"/>
         <location filename="../../KvantumPreviewBase.ui" line="940"/>
         <source>Simple check box</source>
-        <translation type="unfinished"></translation>
+        <translation>Perus valintaruutu</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="950"/>
         <location filename="../../KvantumPreviewBase.ui" line="961"/>
         <source>Multi-line
 check box</source>
-        <translation type="unfinished"></translation>
+        <translation>Monirivinen valintaruutu</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="969"/>
         <location filename="../../KvantumPreviewBase.ui" line="982"/>
         <source>Tri-state check box</source>
-        <translation type="unfinished"></translation>
+        <translation>Kolmiosainen valintaruutu</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="992"/>
         <location filename="../../KvantumPreviewBase.ui" line="1006"/>
         <source>Check box with icon</source>
-        <translation type="unfinished"></translation>
+        <translation>Valintaruutu ja kuvake</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="1062"/>
         <source>Combos/Spins/Inputs</source>
-        <translation type="unfinished"></translation>
+        <translation>Yhdistelmät/kierrokset/tulot</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="1096"/>
@@ -210,37 +238,37 @@ check box</source>
         <location filename="../../KvantumPreviewBase.ui" line="1437"/>
         <location filename="../../KvantumPreviewBase.ui" line="1495"/>
         <source>Frameless (no difference)</source>
-        <translation type="unfinished"></translation>
+        <translation>Kehyksetön (ei eroa)</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="1107"/>
         <location filename="../../KvantumPreviewBase.ui" line="1146"/>
         <source>Standard combo box</source>
-        <translation type="unfinished"></translation>
+        <translation>Vakio yhdistelmäruutu</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="1116"/>
         <location filename="../../KvantumPreviewBase.ui" line="1155"/>
         <source>Standard combo box 1</source>
-        <translation type="unfinished"></translation>
+        <translation>Vakio yhdistelmäruutu 1</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="1124"/>
         <location filename="../../KvantumPreviewBase.ui" line="1160"/>
         <source>Standard combo box 2</source>
-        <translation type="unfinished"></translation>
+        <translation>Vakio yhdistelmäruutu 2</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="1129"/>
         <location filename="../../KvantumPreviewBase.ui" line="1165"/>
         <source>Standard combo box 3</source>
-        <translation type="unfinished"></translation>
+        <translation>Vakio yhdistelmäruutu 3</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="1134"/>
         <location filename="../../KvantumPreviewBase.ui" line="1170"/>
         <source>Standard combo box 4</source>
-        <translation type="unfinished"></translation>
+        <translation>Vakio yhdistelmäruutu 4</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="1191"/>
@@ -248,7 +276,7 @@ check box</source>
         <location filename="../../KvantumPreviewBase.ui" line="1374"/>
         <location filename="../../KvantumPreviewBase.ui" line="1446"/>
         <source>Frameless 1</source>
-        <translation type="unfinished"></translation>
+        <translation>Kehyksetön 1</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="1196"/>
@@ -256,7 +284,7 @@ check box</source>
         <location filename="../../KvantumPreviewBase.ui" line="1379"/>
         <location filename="../../KvantumPreviewBase.ui" line="1451"/>
         <source>Frameless 2</source>
-        <translation type="unfinished"></translation>
+        <translation>Kehyksetön 2</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="1201"/>
@@ -264,7 +292,7 @@ check box</source>
         <location filename="../../KvantumPreviewBase.ui" line="1384"/>
         <location filename="../../KvantumPreviewBase.ui" line="1456"/>
         <source>Frameless 3</source>
-        <translation type="unfinished"></translation>
+        <translation>Kehyksetön 3</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="1206"/>
@@ -272,376 +300,376 @@ check box</source>
         <location filename="../../KvantumPreviewBase.ui" line="1389"/>
         <location filename="../../KvantumPreviewBase.ui" line="1461"/>
         <source>Frameless 4</source>
-        <translation type="unfinished"></translation>
+        <translation>Kehyksetön 4</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="1211"/>
         <location filename="../../KvantumPreviewBase.ui" line="1394"/>
         <source>Frameless 5</source>
-        <translation type="unfinished"></translation>
+        <translation>Kehyksetön 5</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="1216"/>
         <location filename="../../KvantumPreviewBase.ui" line="1399"/>
         <source>Frameless 6</source>
-        <translation type="unfinished"></translation>
+        <translation>Kehyksetön 6</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="1221"/>
         <location filename="../../KvantumPreviewBase.ui" line="1404"/>
         <source>Frameless 7</source>
-        <translation type="unfinished"></translation>
+        <translation>Kehyksetön 7</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="1226"/>
         <location filename="../../KvantumPreviewBase.ui" line="1409"/>
         <source>Frameless 8</source>
-        <translation type="unfinished"></translation>
+        <translation>Kehyksetön 8</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="1231"/>
         <location filename="../../KvantumPreviewBase.ui" line="1414"/>
         <source>Frameless 9</source>
-        <translation type="unfinished"></translation>
+        <translation>Kehyksetön 9</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="1236"/>
         <location filename="../../KvantumPreviewBase.ui" line="1419"/>
         <source>Frameless 10</source>
-        <translation type="unfinished"></translation>
+        <translation>Kehyksetön 10</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="1287"/>
         <location filename="../../KvantumPreviewBase.ui" line="1326"/>
         <source>Editable combo box</source>
-        <translation type="unfinished"></translation>
+        <translation>Muokattava yhd.ruutu</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="1296"/>
         <location filename="../../KvantumPreviewBase.ui" line="1335"/>
         <source>Editable combo box 1</source>
-        <translation type="unfinished"></translation>
+        <translation>Muokattava yhd.ruutu 1</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="1301"/>
         <location filename="../../KvantumPreviewBase.ui" line="1340"/>
         <source>Editable combo box 2</source>
-        <translation type="unfinished"></translation>
+        <translation>Muokattava yhd.ruutu 2</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="1306"/>
         <location filename="../../KvantumPreviewBase.ui" line="1345"/>
         <source>Editable combo box 3</source>
-        <translation type="unfinished"></translation>
+        <translation>Muokattava yhd.ruutu 3</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="1311"/>
         <location filename="../../KvantumPreviewBase.ui" line="1350"/>
         <source>Editable combo box 4</source>
-        <translation type="unfinished"></translation>
+        <translation>Muokattava yhd.ruutu 4</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="1469"/>
         <location filename="../../KvantumPreviewBase.ui" line="1482"/>
         <source>Line-edit</source>
-        <translation type="unfinished"></translation>
+        <translation>Rivin muokkaus</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="1561"/>
         <source>Sliders/Scrolls/Progress/Dial</source>
-        <translation type="unfinished"></translation>
+        <translation>Liukusäätimet/rullat/kulku/valitsin</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="2118"/>
         <source>Containers</source>
-        <translation type="unfinished"></translation>
+        <translation>Laatikot</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="2139"/>
         <source>Header 1</source>
-        <translation type="unfinished"></translation>
+        <translation>Otsikko 1</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="2148"/>
         <source>Header 2</source>
-        <translation type="unfinished"></translation>
+        <translation>Otsikko 2</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="2156"/>
         <source>Header 3</source>
-        <translation type="unfinished"></translation>
+        <translation>Otsikko 3</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="2161"/>
         <source>3rd Item</source>
-        <translation type="unfinished"></translation>
+        <translation>3. Kohde</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="2169"/>
         <source>2nd Item</source>
-        <translation type="unfinished"></translation>
+        <translation>2. Kohde</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="2173"/>
         <location filename="../../KvantumPreviewBase.ui" line="2209"/>
         <source>2nd Child</source>
-        <translation type="unfinished"></translation>
+        <translation>2. Ali</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="2178"/>
         <location filename="../../KvantumPreviewBase.ui" line="2214"/>
         <source>1st Child</source>
-        <translation type="unfinished"></translation>
+        <translation>1. Ali</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="2184"/>
         <source>1st Item</source>
-        <translation type="unfinished"></translation>
+        <translation>1. Kohde</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="2204"/>
         <source>3rd Child</source>
-        <translation type="unfinished"></translation>
+        <translation>3. Ali</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="2462"/>
         <source>Row 0</source>
-        <translation type="unfinished"></translation>
+        <translation>Rivi 0</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="2467"/>
         <source>Row 1</source>
-        <translation type="unfinished"></translation>
+        <translation>Rivi 1</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="2472"/>
         <source>Column 0</source>
-        <translation type="unfinished"></translation>
+        <translation>Sarake 0</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="2480"/>
         <source>Column 1</source>
-        <translation type="unfinished"></translation>
+        <translation>Sarake 1</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="2485"/>
         <source>0-0</source>
-        <translation type="unfinished"></translation>
+        <translation>0-0</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="2493"/>
         <source>0-1</source>
-        <translation type="unfinished"></translation>
+        <translation>0-1</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="2501"/>
         <source>1-0</source>
-        <translation type="unfinished"></translation>
+        <translation>1-0</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="2509"/>
         <source>1-1</source>
-        <translation type="unfinished"></translation>
+        <translation>1-1</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="2191"/>
         <location filename="../../KvantumPreviewBase.ui" line="2194"/>
         <source>Editable</source>
-        <translation type="unfinished"></translation>
+        <translation>muokattava</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="2221"/>
         <source>Non-Editable</source>
-        <translation type="unfinished"></translation>
+        <translation>Ei muokattava</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="2229"/>
         <source>Subwindow</source>
-        <translation type="unfinished"></translation>
+        <translation>Ikkuna</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="2276"/>
         <source>Panel frame</source>
-        <translation type="unfinished"></translation>
+        <translation>Paneelin runko</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="2295"/>
         <location filename="../../KvantumPreviewBase.ui" line="2436"/>
         <location filename="../../KvantumPreviewBase.ui" line="2528"/>
         <source>GroupBox</source>
-        <translation type="unfinished"></translation>
+        <translation>Ryhmälaatikko</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="2315"/>
         <location filename="../../KvantumPreviewBase.ui" line="2367"/>
-        <location filename="../../KvantumPreviewBase.ui" line="2658"/>
-        <location filename="../../KvantumPreviewBase.ui" line="2735"/>
-        <location filename="../../KvantumPreviewBase.ui" line="2783"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2661"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2738"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2786"/>
         <source>Tab 1</source>
-        <translation type="unfinished"></translation>
+        <translation>Välilehti 1</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="2321"/>
         <source>Page 1 (disabled)</source>
-        <translation type="unfinished"></translation>
+        <translation>Sivu 1 (poistettu)</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="2333"/>
         <location filename="../../KvantumPreviewBase.ui" line="2381"/>
-        <location filename="../../KvantumPreviewBase.ui" line="2676"/>
-        <location filename="../../KvantumPreviewBase.ui" line="2749"/>
-        <location filename="../../KvantumPreviewBase.ui" line="2797"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2679"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2752"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2800"/>
         <source>Tab 2</source>
-        <translation type="unfinished"></translation>
+        <translation>Välilehti 2</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="2339"/>
         <source>Page 2 (disabled)</source>
-        <translation type="unfinished"></translation>
+        <translation>Sivu 2 (poistettu)</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="2373"/>
         <location filename="../../KvantumPreviewBase.ui" line="2566"/>
         <location filename="../../KvantumPreviewBase.ui" line="2621"/>
-        <location filename="../../KvantumPreviewBase.ui" line="2741"/>
-        <location filename="../../KvantumPreviewBase.ui" line="2789"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2744"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2792"/>
         <source>Page 1</source>
-        <translation type="unfinished"></translation>
+        <translation>Sivu 1</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="2387"/>
         <location filename="../../KvantumPreviewBase.ui" line="2594"/>
         <location filename="../../KvantumPreviewBase.ui" line="2634"/>
-        <location filename="../../KvantumPreviewBase.ui" line="2682"/>
-        <location filename="../../KvantumPreviewBase.ui" line="2755"/>
-        <location filename="../../KvantumPreviewBase.ui" line="2803"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2685"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2758"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2806"/>
         <source>Page 2</source>
-        <translation type="unfinished"></translation>
+        <translation>Sivu 2</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="2411"/>
         <source>Stack widget (page1)</source>
-        <translation type="unfinished"></translation>
+        <translation>Sovelman (sivu1)</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="2425"/>
         <source>Stack Widget (page2)</source>
-        <translation type="unfinished"></translation>
+        <translation>Sovelman (sivu2)</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="2442"/>
         <source>Group box</source>
-        <translation type="unfinished"></translation>
+        <translation>Ryhmäruutu</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="2520"/>
         <source>Dock Widget</source>
-        <translation type="unfinished"></translation>
+        <translation>Paneelin sovelma</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="2537"/>
         <source>Checkable group box</source>
-        <translation type="unfinished"></translation>
+        <translation>Rastitettava ruutu</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="2572"/>
         <source>Tool Box</source>
-        <translation type="unfinished"></translation>
+        <translation>Työkaluruutu</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2664"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2667"/>
         <source>Document mode</source>
-        <translation type="unfinished"></translation>
+        <translation>Asiakirja tila</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2702"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2705"/>
         <source>Box frame</source>
-        <translation type="unfinished"></translation>
+        <translation>Ruudun kehys</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2832"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2835"/>
         <source>&amp;File</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Tiedosto</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2836"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2839"/>
         <source>&amp;Submenu</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Alivalikko</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2856"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2859"/>
         <source>toolBar</source>
-        <translation type="unfinished"></translation>
+        <translation>Työkalurivi</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2873"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2879"/>
         <source>toolBar_2</source>
-        <translation type="unfinished"></translation>
+        <translation>Työkalurivi_2</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2892"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2901"/>
         <source>&amp;Quit</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Sulje</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2895"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2904"/>
         <source>Quit</source>
-        <translation type="unfinished"></translation>
+        <translation>Sulje</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2898"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2907"/>
         <source>Ctrl+Q</source>
-        <translation type="unfinished"></translation>
+        <translation>Ctrl+Q</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2906"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2915"/>
         <source>&amp;Checkbox</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Valintaruutu</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2919"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2928"/>
         <source>Toggle Layout</source>
-        <translation type="unfinished"></translation>
+        <translation>Vaihda asettelua</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2922"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2931"/>
         <source>Toggle layout direction</source>
-        <translation type="unfinished"></translation>
+        <translation>Vaihda asettelun suunta</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2934"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2943"/>
         <source>&amp;Doc Mode</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Asiakirjat</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2937"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2946"/>
         <source>Show tabs in the document mode</source>
-        <translation type="unfinished"></translation>
+        <translation>Näytä välilehdet asiakirja tilassa</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2949"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2958"/>
         <source>Menu Button</source>
-        <translation type="unfinished"></translation>
+        <translation>Valikkopainike</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2952"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2961"/>
         <source>Hold pressed to show a menu</source>
-        <translation type="unfinished"></translation>
+        <translation>Pidä painettuna valikon näyttämiseksi</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2963"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2972"/>
         <source>C&amp;heckbox</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Valintaruutu</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2971"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2980"/>
         <source>&amp;Radio button</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Valintapainike</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2979"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2988"/>
         <source>Radio &amp;button</source>
-        <translation type="unfinished"></translation>
+        <translation>Valinta&amp;painike</translation>
     </message>
 </context>
 </TS>
