@@ -25,7 +25,11 @@
 #include <QToolButton>
 
 #include "shortcuthandler.h"
+#if (QT_VERSION >= QT_VERSION_CHECK(5,15,0))
 #include "drag/windowmanager.h"
+#else
+#include "drag/windowmanager-old.h"
+#endif
 #include "themeconfig/ThemeConfig.h"
 #include "blur/blurhelper.h"
 #include "animation/animation.h"
@@ -272,10 +276,10 @@ class Style : public QCommonStyle {
     void drawFocusRect(QPainter *painter, const QRect &rect, const QString &element) const;
 
     /* Draws the lineedit of an editable combobox. */
-    void drawComboLineEdit (const QStyleOption *option,
-                            QPainter *painter,
-                            const QWidget *lineedit,
-                            const QWidget *combo) const;
+    void drawComboLineEdit(const QStyleOption *option,
+                           QPainter *painter,
+                           const QWidget *lineedit,
+                           const QWidget *combo) const;
 
     /* Gets a pixmap with a proper size from an icon considering HDPI. */
     QPixmap getPixmapFromIcon(const QIcon &icon,
@@ -313,8 +317,8 @@ class Style : public QCommonStyle {
     }
 
     QWidget* getParent(const QWidget *widget, int level) const;
-    bool enoughContrast (const QColor& col1, const QColor& col2) const;
-    QColor overlayColor(const QColor& bgCol, const QColor& overlayCol) const;
+    bool enoughContrast(const QColor &col1, const QColor &col2) const;
+    QColor overlayColor(const QColor &bgCol, const QColor &overlayCol) const;
 
     /* Can an expanded border be drawn for this frame? */
     bool hasExpandedBorder(const frame_spec &fspec) const;
@@ -325,10 +329,10 @@ class Style : public QCommonStyle {
 
     /* Get menu margins, including its shadow. */
     int getMenuMargin(bool horiz) const;
-    /* Get pure shadow dimensions of menus/tooltips. */
-    QList<qreal> getShadow(const QString &widgetName, int thicknessH, int thicknessV);
-    QList<qreal> getShadow(const QString &widgetName, int thickness) {
-      return getShadow(widgetName,thickness,thickness);
+    /* Get pure shadow dimensions of menus/tooltips (when compositing is available). */
+    void getShadow(const QString &widgetName, int thicknessH, int thicknessV);
+    void getShadow(const QString &widgetName, int thickness) {
+      getShadow(widgetName,thickness,thickness);
     }
 
     /* If this menubar is merged with a toolbar, return the toolbar height! */
@@ -392,6 +396,12 @@ class Style : public QCommonStyle {
     void startAnimation(Animation *animation) const;
     void stopAnimation(const QObject *target) const;
 
+    /* Forcing palettes when needed: */
+    void forcePalette(QWidget *widget, const QPalette &p) const;
+
+    /* Checking whether dragging from buttons is enabled and in progress: */
+    bool btnDragInProgress() const;
+
   private slots:
     /* Called on timer timeout to advance busy progress bars. */
     void advanceProgressbar();
@@ -455,20 +465,15 @@ class Style : public QCommonStyle {
     /* For identifying KisSliderSpinBox */
     bool isKisSlider_;
 
-    /* For having clear label icons with QT_DEVICE_PIXEL_RATIO > 1 */
-    qreal pixelRatio_;
-
     /* Keep track of the sunken button (used instead of a private header for menu positioning). */
     //mutable KvPointer<QWidget> sunkenButton_;
     mutable QPointer<QWidget> sunkenButton_;
 
-    /* Keep track of the widget in which the mouse cursor is entered (to work around Qt scroll jumps). */
-    QPointer<QWidget> enteredWidget_;
-
-    /* For not getting the menu shadows repeatedly.
-       They're used to position menus correctly and also to find blurred regions. */
+    /* For not getting the menu/tooltip shadows repeatedly.
+       They're used to find blurred regions and also to position menus correctly. */
     QList<qreal> menuShadow_;
     QList<int> realMenuShadow_;
+    QList<qreal> tooltipShadow_;
 
     /* Is this DE GTK-based? Currently Gnome, Unity and Pantheon are supported. */
     bool gtkDesktop_;
