@@ -23,6 +23,7 @@
 #include <QVector>
 #include <QMenu>
 #include <QFrame>
+#include <QWindow> // for hdpi
 #include <QApplication> // for hdpi
 
 #if (QT_VERSION >= QT_VERSION_CHECK(5,11,0))
@@ -141,12 +142,11 @@ QRegion BlurHelper::blurRegion (QWidget* widget) const
     r = tooltipShadow_;
   }
 
-  qreal dpr = 1.0;
+  qreal dpr = static_cast<qreal>(1);
   /* KDE blur effect supports HDPI after Qt 5.11 */
 #if (QT_VERSION <= QT_VERSION_CHECK(5,11,0))
   dpr = qApp->devicePixelRatio();
-  if (dpr < 1.0) dpr = 1.0;
-  if (dpr > 1.0)
+  if (dpr > static_cast<qreal>(1))
     rect.setSize ((QSizeF(rect.size()) * dpr).toSize());
 #endif
 
@@ -230,6 +230,5 @@ void BlurHelper::clear (QWidget* widget) const
 #else
   Q_UNUSED (widget);
 #endif
-  return;
 }
 }
