@@ -1,8 +1,5 @@
-// Adapted from oxygenwindowmanager.cpp svnversion: 1139230
-// and QtCurve's windowmanager.cpp v1.8.17
-
 /*
- * Copyright (C) Pedram Pourang (aka Tsu Jan) 2014-2019 <tsujan2000@gmail.com>
+ * Copyright (C) Pedram Pourang (aka Tsu Jan) 2020 <tsujan2000@gmail.com>
  *
  * Kvantum is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -24,9 +21,11 @@
 #include <QBasicTimer>
 #include <QSet>
 #include <QPointer>
+#include <QWindow>
 #include <QWidget>
 
 namespace Kvantum {
+
 class WindowManager: public QObject
 {
   Q_OBJECT
@@ -40,8 +39,7 @@ public:
     DRAG_COUNT
   };
 
-  static Drag toDrag (const QString &str)
-  {
+  static Drag toDrag (const QString &str) {
     for (int i = 0; i < DRAG_COUNT; ++i)
     {
       if (toStr (static_cast<Drag>(i)) == str)
@@ -50,8 +48,7 @@ public:
     return DRAG_NONE;
   }
 
-  static QString toStr (Drag drag)
-  {
+  static QString toStr (Drag drag) {
     switch (drag)
     {
       default:
@@ -62,74 +59,61 @@ public:
     }
   }
 
-  explicit WindowManager (QObject *parent, Drag drag);
+  explicit WindowManager (QObject *parent, Drag drag, bool dragFromBtns);
   virtual ~WindowManager() {}
 
-  void initialize (const QStringList &whiteList=QStringList(),
-                   const QStringList &blackList=QStringList());
+  void initialize (const QStringList &blackList = QStringList());
+
+  void registerWidget (QWidget *widget);
+  void unregisterWidget (QWidget *widget);
+  virtual bool eventFilter (QObject *object, QEvent *event);
+
+  /* needed by the workaround of hover bug in "Kvantum.cpp" */
+  bool dragInProgress() const {
+    return dragInProgress_;
+  }
 
-  void registerWidget (QWidget*);
-  void unregisterWidget (QWidget*);
-  virtual bool eventFilter (QObject*, QEvent*);
 protected:
-  // timer event,
-  /* used to start drag if button is pressed for a long enough time */
-  void timerEvent (QTimerEvent*);
-  bool mousePressEvent (QObject*, QEvent*);
-  bool mouseMoveEvent (QObject*, QEvent*);
-  bool mouseReleaseEvent (QObject*, QEvent*);
-  bool enabled() const
-  {
+  void timerEvent (QTimerEvent *event);
+  bool mousePressEvent (QObject *object, QEvent *event);
+  bool mouseMoveEvent (QEvent *event);
+  bool mouseReleaseEvent (QEvent *event);
+  bool leavingWindow();
+  void widgetMouseRelease (bool inside = false);
+
+  bool enabled() const {
     return enabled_;
   }
-  void setEnabled (bool value)
-  {
+  void setEnabled (bool value) {
     enabled_ = value;
   }
-  // drag distance (pixels)
-  void setDragDistance (int value)
-  {
-    dragDistance_ = value;
-  }
-  // drag delay (msec)
-  void setDragDelay (int value)
-  {
-    dragDelay_ = value;
-  }
 
-  void initializeWhiteList (const QStringList &list);
   void initializeBlackList (const QStringList &list);
-  bool isDragable (QWidget*);
-  bool isBlackListed (QWidget*);
-  bool isWhiteListed (QWidget*) const;
-  // returns true if drag can be started from current widget
-  bool canDrag (QWidget*);
-  bool canDrag (QWidget*, QWidget*, const QPoint&);
+  bool isBlackListed (QWidget *widget);
+  bool canDrag (QWidget *widget);
+  bool isDraggable (QWidget *widget);
   void resetDrag();
-  void startDrag (QWidget*, const QPoint&);
-  bool isDockWidgetTitle (const QWidget*) const;
 
-  void setLocked (bool value)
-  {
-    locked_ = value;
-  }
-  bool isLocked() const
-  {
+  bool isLocked() const {
     return locked_;
   }
+  void unlock() {
+    locked_ = false;
+    dragInProgress_ = false;
+  }
+
 private:
-  // the value of QT_DEVICE_PIXEL_RATIO
-  qreal pixelRatio_;
   bool enabled_;
   int dragDistance_;
   int dragDelay_;
+  int doubleClickInterval_;
+  bool isDelayed_;
 
   // wrapper for exception id
   class ExceptionId: public QPair<QString, QString>
   {
   public:
-    ExceptionId (const QString &value)
-    {
+    ExceptionId (const QString &value) {
       const QStringList args (value.split (QStringLiteral("@")));
       if (args.isEmpty())
         return;
@@ -137,57 +121,54 @@ private:
       if (args.size() > 1)
         first = args[1].trimmed();
     }
-    const QString& appName() const
-    {
-            return first;
+    const QString& appName() const {
+      return first;
     }
-    const QString& className() const
-    {
-            return second;
+    const QString& className() const {
+      return second;
     }
   };
 
   typedef QSet<ExceptionId> ExceptionSet;
-  ExceptionSet whiteList_;
   ExceptionSet blackList_;
 
-  QPoint dragPoint_;
+  QPoint widgetDragPoint_;
   QPoint globalDragPoint_;
+  QPoint lastWinDragPoint_; // used to find double clicks
   QBasicTimer dragTimer_;
-  QPointer<QWidget> target_;
+  QBasicTimer doubleClickTimer_;
+  QPointer<QWindow> winTarget_;
+  QPointer<QWindow> lastWin_;
+  QPointer<QWidget> widgetTarget_;
+  QPointer<QWidget> pressedWidget_;
+  QPointer<QWidget> lastPressedWidget_;
   bool dragAboutToStart_;
   bool dragInProgress_;
   bool locked_;
+  bool dragFromBtns_;
   Drag drag_;
-#if (QT_VERSION >= QT_VERSION_CHECK(5,11,0))
-  bool cursorOverride_;
-#endif
 
-  // provide application-wise event filter
   /*
-    it is used to unlock dragging and make sure event look
-    is properly restored after a drag has occurred
+     provide application-wise event filter
+     (used to unlock dragging and checking some mouse events)
   */
   class AppEventFilter: public QObject
   {
   public:
     AppEventFilter (WindowManager *parent) :
-                   QObject (parent),
-                   parent_ (parent)
-    {}
-  virtual bool eventFilter (QObject*, QEvent*);
-  protected:
-    // application-wise event.
-    /* needed to catch end of XMoveResize events */
-    bool appMouseEvent (QObject*, QEvent*);
+                    QObject (parent),
+                    parent_ (parent) {}
+    virtual bool eventFilter (QObject *object, QEvent *event);
+
   private:
     WindowManager *parent_;
   };
 
   AppEventFilter *_appEventFilter;
-  // allow access of all private members to the app event filter
+  /* allow access of all private members to the app event filter */
   friend class AppEventFilter;
 };
+
 }
 
 #endif
