@@ -1,5 +1,5 @@
 /*
- * Copyright (C) Pedram Pourang (aka Tsu Jan) 2014-2019 <tsujan2000@gmail.com>
+ * Copyright (C) Pedram Pourang (aka Tsu Jan) 2014-2020 <tsujan2000@gmail.com>
  *
  * Kvantum is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -232,19 +232,17 @@ bool Style::eventFilter(QObject *o, QEvent *e)
                /*&& tspec_.translucent_windows*/ // this could have weird effects with style or settings change
               )
       {
-        switch (w->windowFlags() & Qt::WindowType_Mask) {
-          case Qt::Window:
-          case Qt::Dialog:
-          case Qt::Popup:
-          case Qt::ToolTip:
-          case Qt::Sheet: {
-            if (qobject_cast<QMenu*>(w)) break;
-            QPainter p(w);
-            p.setClipRegion(static_cast<QPaintEvent*>(e)->region());
-            drawBg(&p,w);
-            break;
-          }
-          default: break;
+        int t = (w->windowFlags() & Qt::WindowType_Mask);
+        if (t == Qt::Window || t == Qt::Dialog
+            || t == Qt::Popup || t == Qt::ToolTip || t == Qt::Sheet
+            /* the window type may have changed after polishing
+               but we accept Qt::Tool (as with a dialog in Krita) */
+            || (t == Qt::Tool && forcedTranslucency_.contains(w)))
+        {
+          if (qobject_cast<QMenu*>(w)) break; // QMenu has a filter event too
+          QPainter p(w);
+          p.setClipRegion(static_cast<QPaintEvent*>(e)->region());
+          drawBg(&p,w);
         }
       }
       else if (!w->underMouse() && w->inherits("KMultiTabBarTab"))
@@ -338,7 +336,10 @@ bool Style::eventFilter(QObject *o, QEvent *e)
             col = getFromRGBA(lspec.normalColor);
         }
         if (col.isValid())
+        {
+          opacifyColor(col);
           pPalette.setColor(QPalette::ButtonText, col);
+        }
 
         /* icon */
         if (!cbtn->icon().isNull())
@@ -352,7 +353,13 @@ bool Style::eventFilter(QObject *o, QEvent *e)
         if (!styleHint(QStyle::SH_UnderlineShortcut, &option, cbtn))
           textflags |= Qt::TextHideMnemonic;
         textflags |= Qt::AlignTop; // (see Kvantum.cpp -> Style::drawItemText)
+        if (cbtn->layoutDirection() == Qt::RightToLeft)
+          textflags |= Qt::AlignRight;
+        else
+          textflags |= Qt::AlignLeft;
 
+        /* This is what QCommandLinkButtonPrivate::titleFont() does.
+           It's bad because the font shouldn't be fixed. */
         QFont titleFont = cbtn->font();
         titleFont.setBold(true);
         titleFont.setPointSizeF(9.0);
@@ -374,7 +381,7 @@ bool Style::eventFilter(QObject *o, QEvent *e)
         /* description */
         textflags |= Qt::TextWordWrap | Qt::ElideRight;
         QFont descriptionFont = cbtn->font();
-        descriptionFont.setPointSizeF(9.0);
+        descriptionFont.setPointSizeF(9.0); // -> QCommandLinkButtonPrivate::descriptionFont()
         p.setFont(descriptionFont);
         QFontMetrics fm(titleFont);
         int descriptionOffset = topMargin + fm.height();
@@ -388,36 +395,6 @@ bool Style::eventFilter(QObject *o, QEvent *e)
     }
     break;
 
-  case QEvent::Enter:
-    if (w && hspec_.scroll_jump_workaround)
-    {
-      if (qobject_cast<QLineEdit*>(o))
-      { // consider the special case of a spin box
-        if (QAbstractSpinBox *sb = qobject_cast<QAbstractSpinBox*>(w->parentWidget()))
-        {
-          enteredWidget_ = sb;
-          break;
-        }
-      }
-      /* In the case of Dolphin, first KItemListContainerViewport is entered
-         and then only a QWidget, which ruins our workaround. Fortunately,
-         KItemListContainerViewport is the parent of that QWidget. */
-      if (enteredWidget_ && enteredWidget_.data()->inherits("KItemListContainerViewport")
-          && w->parentWidget() == enteredWidget_)
-      {
-        break;
-      }
-      enteredWidget_ = w;
-      /* NOTE: Qt doc says, "If multiple event filters are installed on a single object,
-               the filter that was installed last is activated first." Because an event
-               filter can be installed by the app without polishing the widget (like when
-               the view is switched in pcmanfm-qt between the icon and thumbnail modes),
-               we need to reinstall the event filter here to catch the wheel event always
-               before it's processed by the app. */
-      w->installEventFilter(this);
-    }
-    break;
-
   case QEvent::HoverMove:
     if (QTabBar *tabbar = qobject_cast<QTabBar*>(o))
     { // see QEvent::HoverEnter below
@@ -497,7 +474,8 @@ bool Style::eventFilter(QObject *o, QEvent *e)
         tabHoverRect_ = QRect();
     }
     else if (w && w->isEnabled() && tspec_.animate_states
-             && !w->isWindow() // WARNING: Translucent (Qt5) windows have enter event!
+             /* WARNING: Toolbars and translucent windows have hover-enter event! */
+             && !w->isWindow() && !qobject_cast<QToolBar*>(o)
              && !qobject_cast<QAbstractSpinBox*>(o) && !qobject_cast<QProgressBar*>(o)
              && !qobject_cast<QLineEdit*>(o) && !qobject_cast<QAbstractScrollArea*>(o)
              && !((tspec_.combo_as_lineedit || tspec_.square_combo_button)
@@ -843,19 +821,22 @@ bool Style::eventFilter(QObject *o, QEvent *e)
       const label_spec lspec = getLabelSpec(QStringLiteral("ItemView"));
       /* set the normal inactive text color to the normal active one
          (needed when the app sets it inactive) */
-      QColor normalCol = getFromRGBA(lspec.normalColor);
-      if (!normalCol.isValid())
-        normalCol = standardPalette().color(QPalette::Active,QPalette::Text);
-      palette.setColor(QPalette::Inactive, QPalette::Text, normalCol);
+      QColor col = getFromRGBA(lspec.normalColor);
+      if (!col.isValid())
+        col = standardPalette().color(QPalette::Active,QPalette::Text);
+      else
+        opacifyColor(col);
+      palette.setColor(QPalette::Inactive, QPalette::Text, col);
       if (!hasInactiveSelItemCol_)
       {
-        w->setPalette(palette);
+        forcePalette(w, palette);
         break;
       }
       /* set the toggled inactive text color to the toggled active one
          (the main purpose of installing an event filter on the view) */
-      palette.setColor(QPalette::Inactive, QPalette::HighlightedText,
-                       getFromRGBA(lspec.toggleColor));
+      col = getFromRGBA(lspec.toggleColor);
+      opacifyColor(col);
+      palette.setColor(QPalette::Inactive, QPalette::HighlightedText, col);
       /* use the active highlight color for the toggled (unfocused) item if there's
          no contrast with the pressed state because some apps (like Qt Designer)
          may not call PE_PanelItemViewItem but highlight the item instead */
@@ -864,7 +845,7 @@ bool Style::eventFilter(QObject *o, QEvent *e)
         palette.setColor(QPalette::Inactive, QPalette::Highlight,
                          standardPalette().color(QPalette::Active,QPalette::Highlight));
       }
-      w->setPalette(palette);
+      forcePalette(w, palette);
     }
     break;
 
@@ -879,25 +860,28 @@ bool Style::eventFilter(QObject *o, QEvent *e)
       }
       const label_spec lspec = getLabelSpec(QStringLiteral("ItemView"));
       /* restore the normal inactive text color (which was changed at QEvent::WindowActivate) */
-      QColor normalInactiveCol = getFromRGBA(lspec.normalInactiveColor);
-      if (!normalInactiveCol.isValid())
-        normalInactiveCol = standardPalette().color(QPalette::Inactive,QPalette::Text);
-      palette.setColor(QPalette::Inactive, QPalette::Text, normalInactiveCol);
+      QColor col = getFromRGBA(lspec.normalInactiveColor);
+      if (!col.isValid())
+        col = standardPalette().color(QPalette::Inactive,QPalette::Text);
+      else
+        opacifyColor(col);
+      palette.setColor(QPalette::Inactive, QPalette::Text, col);
       if (!hasInactiveSelItemCol_)
       { // custom text color
-        w->setPalette(palette);
+        forcePalette(w, palette);
         break;
       }
       /* restore the toggled inactive text color (which was changed at QEvent::WindowActivate) */
-      palette.setColor(QPalette::Inactive,QPalette::HighlightedText,
-                       getFromRGBA(lspec.toggleInactiveColor));
+      col = getFromRGBA(lspec.toggleInactiveColor);
+      opacifyColor(col);
+      palette.setColor(QPalette::Inactive,QPalette::HighlightedText, col);
       /* restore the inactive highlight color (which was changed at QEvent::WindowActivate) */
       if (!toggledItemHasContrast_)
       {
         palette.setColor(QPalette::Inactive, QPalette::Highlight,
                          standardPalette().color(QPalette::Inactive,QPalette::Highlight));
       }
-      w->setPalette(palette);
+      forcePalette(w, palette);
     }
     break;
 
@@ -969,11 +953,16 @@ bool Style::eventFilter(QObject *o, QEvent *e)
         }
         /* get the available geometry (Qt menus don't
            spread across the available virtual geometry) */
-        QRect ag;
+        QRect sg, ag;
+        QScreen *sc = nullptr;
         if (QWindow *win = w->windowHandle())
         {
-          if (QScreen *sc = win->screen())
+          sc = win->screen();
+          if (sc)
+          {
+            sg = sc->geometry();
             ag = sc->availableGeometry();
+          }
         }
         qreal dX = 0, dY = 0;
         /* this gives the real position AFTER pending movements
@@ -1046,10 +1035,18 @@ bool Style::eventFilter(QObject *o, QEvent *e)
                 }
                 else if (!ag.isEmpty())
                 {
-                  if (g.bottom() == ag.bottom() && g.top() != ag.top())
+                  if (g.top() != ag.top()
+                      && (g.bottom() == ag.bottom()
+                          || QCursor::pos(sc).y() >= g.bottom()))
+                  {
                     dY += menuShadow_.at(1) + menuShadow_.at(3);
-                  if (g.left() == ag.left() && g.right() != ag.right())
+                  }
+                  if (g.right() != ag.right()
+                      && (g.left() == ag.left()
+                          || QCursor::pos(sc).x() <= g.left()))
+                  {
                     dX -= menuShadow_.at(2) + menuShadow_.at(0);
+                  }
                 }
               }
             }
@@ -1108,12 +1105,20 @@ bool Style::eventFilter(QObject *o, QEvent *e)
                 }
                 else if (!ag.isEmpty()) // probably a panel menu
                 {
-                  /* snap to the screen bottom if possible */
-                  if (g.bottom() == ag.bottom() && g.top() != ag.top())
+                  /* snap to the screen bottom/right if possible and,
+                     as the last resort, consider the cursor position */
+                  if (g.top() != ag.top()
+                      && (g.bottom() == ag.bottom()
+                          || QCursor::pos(sc).y() >= g.bottom()))
+                  {
                     dY += menuShadow_.at(1) + menuShadow_.at(3);
-                  /* snap to the right screen edge if possible */
-                  if (g.right() == ag.right() && g.left() != ag.left())
+                  }
+                  if (g.left() != ag.left()
+                      && (g.right() == ag.right()
+                          || QCursor::pos(sc).x() >= g.right() + 1))
+                  {
                     dX += menuShadow_.at(0) + menuShadow_.at(2);
+                  }
                 }
               }
             }
@@ -1153,6 +1158,21 @@ bool Style::eventFilter(QObject *o, QEvent *e)
         int DX = qRound(dX);
         int DY = qRound(dY);
         if (DX == 0 && DY == 0) break;
+
+        // prevent the menu from switching to another screen
+        if (!sg.isEmpty() && QApplication::screens().size() > 1)
+        {
+          if (g.top() + DY < sg.top() && g.top() >= sg.top())
+            DY = sg.top() - g.top();
+          if (w->layoutDirection() == Qt::RightToLeft)
+          {
+            if (g.right() + DX > sg.right() && g.right() <= sg.right())
+              DX = sg.right() - g.right();
+          }
+          else if (g.left() + DX < sg.left() && g.left() >= sg.left())
+            DX = sg.left() - g.left();
+        }
+
         w->move(g.left() + DX, g.top() + DY);
         movedMenus.insert(w);
       }
@@ -1178,17 +1198,20 @@ bool Style::eventFilter(QObject *o, QEvent *e)
         const label_spec lspec = getLabelSpec(QStringLiteral("ItemView"));
         if (isWidgetInactive(w)) // FIXME: probably not needed with inactive window
         {
-          QColor normalInactiveCol = getFromRGBA(lspec.normalInactiveColor);
-          if (!normalInactiveCol.isValid())
-            normalInactiveCol = standardPalette().color(QPalette::Inactive,QPalette::Text);
-          palette.setColor(QPalette::Inactive, QPalette::Text, normalInactiveCol);
+          QColor col = getFromRGBA(lspec.normalInactiveColor);
+          if (!col.isValid())
+            col = standardPalette().color(QPalette::Inactive,QPalette::Text);
+          else
+            opacifyColor(col);
+          palette.setColor(QPalette::Inactive, QPalette::Text, col);
           if (!hasInactiveSelItemCol_)
           {
-            w->setPalette(palette);
+            forcePalette(w, palette);
             break;
           }
-          palette.setColor(QPalette::Inactive,QPalette::HighlightedText,
-                           getFromRGBA(lspec.toggleInactiveColor));
+          col = getFromRGBA(lspec.toggleInactiveColor);
+          opacifyColor(col);
+          palette.setColor(QPalette::Inactive,QPalette::HighlightedText, col);
           if (!toggledItemHasContrast_)
           {
             palette.setColor(QPalette::Inactive, QPalette::Highlight,
@@ -1197,24 +1220,27 @@ bool Style::eventFilter(QObject *o, QEvent *e)
         }
         else
         {
-          QColor normalCol = getFromRGBA(lspec.normalColor);
-          if (!normalCol.isValid())
-            normalCol = standardPalette().color(QPalette::Active,QPalette::Text);
-          palette.setColor(QPalette::Inactive, QPalette::Text, normalCol);
+          QColor col = getFromRGBA(lspec.normalColor);
+          if (!col.isValid())
+            col = standardPalette().color(QPalette::Active,QPalette::Text);
+          else
+            opacifyColor(col);
+          palette.setColor(QPalette::Inactive, QPalette::Text, col);
           if (!hasInactiveSelItemCol_)
           {
-            w->setPalette(palette);
+            forcePalette(w, palette);
             break;
           }
-          palette.setColor(QPalette::Inactive, QPalette::HighlightedText,
-                           getFromRGBA(lspec.toggleColor));
+          col = getFromRGBA(lspec.toggleColor);
+          opacifyColor(col);
+          palette.setColor(QPalette::Inactive, QPalette::HighlightedText, col);
           if (!toggledItemHasContrast_)
           {
             palette.setColor(QPalette::Inactive, QPalette::Highlight,
                              standardPalette().color(QPalette::Active,QPalette::Highlight));
           }
         }
-        w->setPalette(palette);
+        forcePalette(w, palette);
       }
       else if (gtkDesktop_
                && (!w->parent() || !qobject_cast<QWidget *>(w->parent())
@@ -1228,7 +1254,7 @@ bool Style::eventFilter(QObject *o, QEvent *e)
   /* FIXME For some reason unknown to me (a Qt5 bug?), the Qt5 spinbox size hint
      is sometimes wrong as if Qt5 spinboxes don't have time to consult CT_SpinBox
      although they should (-> qabstractspinbox.cpp -> QAbstractSpinBox::sizeHint).
-     The same thing rarely happens with Qt4 too. Here we force a minimum size by
+     The same thing rarely happened with Qt4 too. Here we force a minimum size by
      using CT_SpinBox when the maximum size isn't set by the app or isn't smaller
      than our size. */
   case QEvent::ShowToParent:
@@ -1239,7 +1265,7 @@ bool Style::eventFilter(QObject *o, QEvent *e)
             || qobject_cast<QDoubleSpinBox*>(o)
             || qobject_cast<QDateTimeEdit*>(o)))
     {
-      QSize size = sizeFromContents(CT_SpinBox,nullptr,QSize(),w);
+      QSize size = sizeFromContents(CT_SpinBox,nullptr,QSize(),w).expandedTo(w->minimumSize());
       if (w->maximumWidth() > size.width())
         w->setMinimumWidth(size.width());
       if (w->maximumHeight() > size.height())
@@ -1251,30 +1277,47 @@ bool Style::eventFilter(QObject *o, QEvent *e)
                  || !getInteriorSpec(QStringLiteral("ToolbarLineEdit")).element.isEmpty())
              && getStylableToolbarContainer(w, true))
     {
-      QPalette palette = w->palette();
       const label_spec tlspec = getLabelSpec("Toolbar");
       QColor col = getFromRGBA(tlspec.normalColor);
-      if (col.isValid() && palette.color(QPalette::Active, QPalette::Text) != col)
+      if (enoughContrast(col, standardPalette().color(QPalette::Active,QPalette::Text)))
       {
-        palette.setColor(QPalette::Active, QPalette::Text, col);
-        QColor col1 = getFromRGBA(tlspec.normalInactiveColor);
-        if (!col1.isValid()) col1 = col;
+        QColor col1 = col;
+        opacifyColor(col1);
+        QPalette palette = w->palette();
+        palette.setColor(QPalette::Active, QPalette::Text, col1);
+        if (!tspec_.no_inactiveness)
+        {
+          col1 = getFromRGBA(tlspec.normalInactiveColor);
+          if (!col1.isValid()) col1 = col;
+          opacifyColor(col1);
+        }
         palette.setColor(QPalette::Inactive, QPalette::Text, col1);
+#if (QT_VERSION >= QT_VERSION_CHECK(5,12,0))
+        col1 = col; // placeholder
+        col1.setAlpha(128);
+        opacifyColor(col1);
+        palette.setColor(QPalette::PlaceholderText, col1);
+#endif
         col.setAlpha(102); // 0.4 * disabledCol.alpha()
+        opacifyColor(col);
         palette.setColor(QPalette::Disabled, QPalette::Text,col);
-        w->setPalette(palette);
+        forcePalette(w, palette);
+#if (QT_VERSION >= QT_VERSION_CHECK(5,12,0))
+        /* also correct the color of the symbolic clear icon (-> CE_ToolBar) */
+        if (QAction *clearAction = w->findChild<QAction*>(QLatin1String("_q_qlineeditclearaction")))
+          clearAction->setIcon(standardIcon(QStyle::SP_LineEditClearButton, nullptr, w));
+#endif
       }
     }
     break;
 
-  case QEvent::Wheel :
-    if (w && enteredWidget_.data() == w/* && hspec_.scroll_jump_workaround*/)
+  case QEvent::PaletteChange :
+    if (!isPcmanfm_ && qobject_cast<QLineEdit*>(o) && (tspec_.combo_as_lineedit || tspec_.square_combo_button))
     {
-      if (QWheelEvent *we = static_cast<QWheelEvent*>(e))
+      if (QComboBox *cb = qobject_cast<QComboBox*>(w->parentWidget()))
       {
-        enteredWidget_.clear();
-        if (we->angleDelta().manhattanLength() >= 240)
-          return true;
+        if (cb->isVisible())
+          cb->update(); // a workaround for bad codes that change line-edit base color
       }
     }
     break;
