@@ -96,7 +96,11 @@ static void setAppFont()
   QString fontName = readDconfSetting("font-name");
   if (!fontName.isEmpty())
   {
+#if (QT_VERSION >= QT_VERSION_CHECK(5,15,0))
+    QStringList parts = fontName.split(' ', Qt::SkipEmptyParts);
+#else
     QStringList parts = fontName.split(' ', QString::SkipEmptyParts);
+#endif
     if (parts.length()>1)
     {
       uint size = parts.takeLast().toUInt();
@@ -109,13 +113,22 @@ static void setAppFont()
   }
 }
 
+/* WARNING: For easily distinguishing animated widgets (-> "eventFiltering.cpp")
+            from others that also have event filter, event filters should be
+            installed with care. */
 void Style::polish(QWidget *widget)
 {
   if (!widget) return;
 
-  // for moving the window containing this widget
+  /* Reset the palette if the widget doesn't have a separate palette.
+     This will be useful if the style changes to Kvantum in runtime. */
+  if (!widget->testAttribute(Qt::WA_SetPalette))
+    widget->setPalette(QPalette());
+
+#if (QT_VERSION < QT_VERSION_CHECK(5,15,0))
   if (itsWindowManager_)
     itsWindowManager_->registerWidget(widget);
+#endif
 
   QWidget *pw = widget->parentWidget();
 
@@ -162,9 +175,14 @@ void Style::polish(QWidget *widget)
       && !qobject_cast<QToolButton*>(widget) // flat toolbuttons are dealt with at CE_ToolButtonLabel
       && getStylableToolbarContainer(widget))
   {
-    QColor inactiveCol = getFromRGBA(tLspec.normalInactiveColor);
-    if (!inactiveCol.isValid())
+    QColor inactiveCol;
+    if (tspec_.no_inactiveness)
       inactiveCol = tColor;
+    else
+    {
+      inactiveCol = getFromRGBA(tLspec.normalInactiveColor);
+      if (!inactiveCol.isValid()) inactiveCol = tColor;
+    }
     QColor disabledCol = tColor;
     disabledCol.setAlpha(102); // 0.4 * disabledCol.alpha()
 #if (QT_VERSION >= QT_VERSION_CHECK(5,12,0))
@@ -196,7 +214,7 @@ void Style::polish(QWidget *widget)
 #endif
         respectDarkness = false; // we don't want to change its text color again
       }
-      widget->setPalette(palette);
+      forcePalette(widget, palette);
     }
 
     if (qobject_cast<QLineEdit*>(widget))
@@ -213,7 +231,7 @@ void Style::polish(QWidget *widget)
 #if (QT_VERSION >= QT_VERSION_CHECK(5,12,0))
           palette.setColor(QPalette::PlaceholderText, ptColor);
 #endif
-          widget->setPalette(palette);
+          forcePalette(widget, palette);
 #if (QT_VERSION >= QT_VERSION_CHECK(5,12,0))
           /* also correct the color of the symbolic clear icon */
           if (QAction *clearAction = widget->findChild<QAction*>(QLatin1String("_q_qlineeditclearaction")))
@@ -238,22 +256,43 @@ void Style::polish(QWidget *widget)
         {
           palette.setColor(QPalette::ButtonText, tColor);
           palette.setColor(QPalette::Disabled,QPalette::ButtonText, disabledCol);
-          widget->setPalette(palette);
+          forcePalette(widget, palette);
         }
       }
     }
   }
-  else if (qobject_cast<QToolBar*>(pw) && qobject_cast<QLabel*>(widget))
-  { // on toolbars, labels get the button text color; that's corrected here
-    QPalette palette = widget->palette();
-    palette.setColor(QPalette::Active, QPalette::ButtonText,
-                     standardPalette().color(QPalette::Active,QPalette::WindowText));
-    palette.setColor(QPalette::Inactive, QPalette::ButtonText,
-                     standardPalette().color(QPalette::Inactive,QPalette::WindowText));
-    palette.setColor(QPalette::Disabled, QPalette::ButtonText,
-                     standardPalette().color(QPalette::Disabled,QPalette::WindowText));
-    widget->setPalette(palette);
-    respectDarkness = false;
+  else if (qobject_cast<QLabel*>(widget))
+  {
+    if (qobject_cast<QToolBar*>(pw))
+    { // on toolbars, labels get the button text color; that's corrected here
+      QPalette palette = widget->palette();
+      palette.setColor(QPalette::Active, QPalette::ButtonText,
+                      standardPalette().color(QPalette::Active,QPalette::WindowText));
+      palette.setColor(QPalette::Inactive, QPalette::ButtonText,
+                      standardPalette().color(QPalette::Inactive,QPalette::WindowText));
+      palette.setColor(QPalette::Disabled, QPalette::ButtonText,
+                      standardPalette().color(QPalette::Disabled,QPalette::WindowText));
+      forcePalette(widget, palette);
+      respectDarkness = false;
+    }
+    else if (qobject_cast<QMenu*>(widget->window()))
+    {
+      /* The label may be shown after its parent menu is polished below, in
+         "switch (widget->windowFlags()...)". Other widgets are ignored for now. */
+      QColor menuTextColor = getFromRGBA(getLabelSpec(QStringLiteral("MenuItem")).normalColor);
+      if (menuTextColor.isValid())
+      {
+        opacifyColor(menuTextColor);
+        if (menuTextColor != standardPalette().color(QPalette::Active,QPalette::WindowText))
+        {
+          QPalette palette = widget->palette();
+          palette.setColor(QPalette::Active,QPalette::WindowText,menuTextColor);
+          palette.setColor(QPalette::Inactive,QPalette::WindowText,menuTextColor);
+          forcePalette(widget, palette);
+          respectDarkness = false;
+        }
+      }
+    }
   }
 
   if (respectDarkness)
@@ -288,7 +327,7 @@ void Style::polish(QWidget *widget)
                 && !enoughContrast(palette.color(QPalette::AlternateBase), txtCol)))
         {
           polish(palette);
-          widget->setPalette(palette);
+          forcePalette(widget, palette);
         }
       }
     }
@@ -300,6 +339,10 @@ void Style::polish(QWidget *widget)
     case Qt::Popup:
     case Qt::ToolTip: // a window, not a real tooltip
     case Qt::Sheet: { // WARNING: What the hell?! On Linux? Yes, a Qt5 bug!
+#if (QT_VERSION >= QT_VERSION_CHECK(5,15,0))
+      if (itsWindowManager_)
+        itsWindowManager_->registerWidget(widget);
+#endif
       QRegion wMask = widget->mask();
       if (!wMask.isEmpty() && wMask != QRegion(widget->rect()))
         break; // like Vokoscreen's QvkAnimateWindow
@@ -331,7 +374,7 @@ void Style::polish(QWidget *widget)
                 palette.setColor(QPalette::AlternateBase,altBaseCol);
               }
             }
-            widget->setPalette(palette);
+            forcePalette(widget, palette);
           }
         }
         break;
@@ -340,8 +383,10 @@ void Style::polish(QWidget *widget)
                || qobject_cast<QLabel*>(widget) // a floating label, as in Filelight
                || widget->inherits("QComboBoxPrivateContainer") // at most, a menu
                /* like Vokoscreen's (old) QvkRegionChoise */
-               || ((widget->windowFlags() & Qt::WindowType_Mask) == Qt::ToolTip
-                   && widget->windowFlags().testFlag(Qt::WindowStaysOnTopHint)))
+               || (widget->windowFlags().testFlag(Qt::WindowStaysOnTopHint)
+                   && widget->testAttribute(Qt::WA_NoSystemBackground)
+                   && ((widget->windowFlags() & Qt::WindowType_Mask) == Qt::ToolTip
+                       || (widget->windowState() & Qt::WindowFullScreen))))
       {
         break;
       }
@@ -452,7 +497,7 @@ void Style::polish(QWidget *widget)
               widget->setAttribute(Qt::WA_TranslucentBackground);
 #else
             if (!widget->testAttribute(Qt::WA_TranslucentBackground)
-                || !widget->testAttribute(Qt::WA_NoSystemBackground))
+                || (makeTranslucent && !widget->testAttribute(Qt::WA_NoSystemBackground)))
             {
               if (!widget->testAttribute(Qt::WA_TranslucentBackground))
                 widget->setAttribute(Qt::WA_TranslucentBackground);
@@ -469,15 +514,14 @@ void Style::polish(QWidget *widget)
               {
                 if (tspec_now.menu_shadow_depth > 0)
                   getShadow(QStringLiteral("Menu"), getMenuMargin(true), getMenuMargin(false));
-                QList<qreal> tooltipS;
                 if (tspec_now.tooltip_shadow_depth > 0)
                 {
                   const frame_spec fspec = getFrameSpec(QStringLiteral("ToolTip"));
                   int thickness = qMax(qMax(fspec.top,fspec.bottom), qMax(fspec.left,fspec.right));
                   thickness += tspec_now.tooltip_shadow_depth;
-                  tooltipS = getShadow(QStringLiteral("ToolTip"), thickness);
+                  getShadow(QStringLiteral("ToolTip"), thickness);
                 }
-                blurHelper_ = new BlurHelper(this, menuShadow_, tooltipS,
+                blurHelper_ = new BlurHelper(this, menuShadow_, tooltipShadow_,
                                              tspec_.contrast, tspec_.intensity, tspec_.saturation);
               }
               if (blurHelper_)
@@ -498,11 +542,8 @@ void Style::polish(QWidget *widget)
 
       break;
     }
-    default: {
-      if (hspec_.scroll_jump_workaround)
-        widget->installEventFilter(this);
+    default:
       break;
-    }
   }
 
   if (isDolphin_
@@ -517,7 +558,7 @@ void Style::polish(QWidget *widget)
                      standardPalette().color(QPalette::Active,QPalette::Base));
     palette.setColor(QPalette::Inactive, widget->backgroundRole(),
                      standardPalette().color(QPalette::Inactive,QPalette::Base));
-    widget->setPalette(palette);
+    forcePalette(widget, palette);
     /* hack Dolphin's view */
     if (hspec_.transparent_dolphin_view && widget->autoFillBackground())
       widget->setAutoFillBackground(false);
@@ -560,14 +601,14 @@ void Style::polish(QWidget *widget)
       altBaseCol = overlayColor(wBaseCol,altBaseCol);
       wp.setColor(QPalette::AlternateBase,altBaseCol);
     }
-    widget->setPalette(wp);
+    forcePalette(widget, wp);
   }
 
   if (widget->inherits("KTitleWidget") && hspec_.transparent_ktitle_label)
   { // -> ktitlewidget.cpp
     /*QPalette palette = widget->palette();
     palette.setColor(QPalette::Base,QColor(Qt::transparent));
-    widget->setPalette(palette);*/
+    forcePalette(widget, palette);*/
     if (QFrame *titleFrame = widget->findChild<QFrame*>())
       titleFrame->setAutoFillBackground(false);
   }
@@ -585,7 +626,7 @@ void Style::polish(QWidget *widget)
   { // needed for combo menu scrollers to have transparent backgrounds
     QPalette palette = widget->palette();
     palette.setColor(widget->backgroundRole(), QColor(Qt::transparent));
-    widget->setPalette(palette);
+    forcePalette(widget, palette);
   }
   else if (qobject_cast<QMdiSubWindow*>(widget))
     /* to integrate the corner area, autoFillBackground isn't set
@@ -605,19 +646,29 @@ void Style::polish(QWidget *widget)
     }
     else // in rare cases like KNotes' font combos or Kcalc
     {
-      QColor col = standardPalette().color(QPalette::Active,QPalette::Text);
       QPalette palette = widget->palette();
-      if (col != palette.color(QPalette::Active,QPalette::Text))
+      if (palette.color(QPalette::Active, QPalette::Base)
+          == standardPalette().color(QPalette::Active, QPalette::Base))
       {
-        palette.setColor(QPalette::Active,QPalette::Text,col);
-        palette.setColor(QPalette::Inactive,QPalette::Text,
-                         standardPalette().color(QPalette::Inactive,QPalette::Text));
-        widget->setPalette(palette);
+        QColor col = standardPalette().color(QPalette::Active,QPalette::Text);
+        if (col != palette.color(QPalette::Active,QPalette::Text))
+        {
+          palette.setColor(QPalette::Active,QPalette::Text,col);
+          palette.setColor(QPalette::Inactive,QPalette::Text,
+                           standardPalette().color(QPalette::Inactive,QPalette::Text));
+          forcePalette(widget, palette);
+        }
       }
     }
 
-    if (qobject_cast<QLineEdit*>(widget) && tspec_.animate_states)
+    if (qobject_cast<QLineEdit*>(widget)
+        && (tspec_.animate_states
+            /* a workaround for bad codes that change line-edit base color */
+            || (!isPcmanfm_ && (tspec_.combo_as_lineedit || tspec_.square_combo_button)
+                && qobject_cast<QComboBox*>(pw))))
+    {
       widget->installEventFilter(this);
+    }
   }
   else if (qobject_cast<QComboBox*>(widget)
            || qobject_cast<QSlider*>(widget))
@@ -659,14 +710,14 @@ void Style::polish(QWidget *widget)
 
             QPalette palette = itemView->palette();
             palette.setColor(itemView->backgroundRole(), QColor(Qt::transparent));
-            itemView->setPalette(palette);
+            forcePalette(itemView, palette);
 
             itemView->viewport()->setAutoFillBackground(false);
             if (baseContrast)
             {
               opacifyColor(menuTextColor);
               vPalette.setColor(QPalette::Text, menuTextColor);
-              itemView->viewport()->setPalette(vPalette);
+              forcePalette(itemView->viewport(), vPalette);
             }
           }
           else if (itemView->itemDelegate()->inherits("QComboBoxDelegate")
@@ -692,7 +743,7 @@ void Style::polish(QWidget *widget)
 
               palette.setColor(QPalette::Base, baseCol);
               palette.setColor(QPalette::Window, winCol);
-              itemView->setPalette(palette);
+              forcePalette(itemView, palette);
               QColor vBgCol;
               if (itemView->viewport())
               {
@@ -708,7 +759,7 @@ void Style::polish(QWidget *widget)
                   sb->setAutoFillBackground(true);
                   palette = sb->palette();
                   palette.setColor(sb->backgroundRole(), vBgCol);
-                  sb->setPalette(palette);
+                  forcePalette(sb, palette);
               }
               if (combo->completer())
               {
@@ -718,7 +769,7 @@ void Style::polish(QWidget *widget)
                     palette.setColor(QPalette::Text, standardPalette().color(QPalette::Text));
                     palette.setColor(QPalette::Base, baseCol);
                     palette.setColor(QPalette::Window, winCol);
-                    cv->setPalette(palette);
+                    forcePalette(cv, palette);
                 }
               }
             }
@@ -835,7 +886,11 @@ void Style::polish(QWidget *widget)
       {
         // support animation only if the background is flat
         if ((tspec_.animate_states
-             && (!vp || vp->autoFillBackground() || !vp->styleSheet().isEmpty())
+             && (!vp || vp->autoFillBackground() || (!vp->styleSheet().isEmpty()
+#if (QT_VERSION >= QT_VERSION_CHECK(5,12,0))
+                 && vp->testAttribute(Qt::WA_StyleSheetTarget)
+#endif
+                ))
              && themeRndr_ && themeRndr_->isValid()) // the default SVG file doesn't have a focus state for frames
            || (hasInactiveSelItemCol_
                && qobject_cast<QAbstractItemView*>(widget))) // enforce the text color of inactive selected items
@@ -846,7 +901,11 @@ void Style::polish(QWidget *widget)
         if ((tspec_.scrollbar_in_view || (widget->inherits("QComboBoxListView")
                                           && (!tspec_.combo_menu /*|| isLibreoffice_*/)))
             && vp && vp->autoFillBackground()
-            && (vp->styleSheet().isEmpty() || !vp->styleSheet().contains("background"))
+            && (
+#if (QT_VERSION >= QT_VERSION_CHECK(5,12,0))
+                !vp->testAttribute(Qt::WA_StyleSheetTarget) ||
+#endif
+                vp->styleSheet().isEmpty() || !vp->styleSheet().contains("background"))
             // but not when the combo popup is drawn as a menu
             && !(tspec_.combo_menu /*&& !isLibreoffice_*/ && widget->inherits("QComboBoxListView"))
             // also consider pcmanfm hacking keys
@@ -871,7 +930,7 @@ void Style::polish(QWidget *widget)
               palette.setColor(sb->backgroundRole(), col);
               if (col1.isValid() && col1 != col)
                 palette.setColor(QPalette::Inactive, sb->backgroundRole(), col1);
-              sb->setPalette(palette);
+              forcePalette(sb, palette);
             }
             if (QScrollBar *sb = sa->verticalScrollBar())
             {
@@ -881,14 +940,14 @@ void Style::polish(QWidget *widget)
               palette.setColor(sb->backgroundRole(), col);
               if (col1.isValid() && col1 != col)
                 palette.setColor(QPalette::Inactive, sb->backgroundRole(), col1);
-              sb->setPalette(palette);
+              forcePalette(sb, palette);
             }
             // FIXME: is this needed?
             palette = widget->palette();
             if (palette.color(vp->backgroundRole()) != col)
             {
               palette.setColor(widget->backgroundRole(), col);
-              widget->setPalette(palette);
+              forcePalette(widget, palette);
             }
           }
         }
@@ -914,7 +973,7 @@ void Style::polish(QWidget *widget)
     QColor shadow = palette.shadow().color();
     shadow.setAlpha(0);
     palette.setColor(QPalette::Shadow, shadow);
-    widget->setPalette(palette);
+    forcePalette(widget, palette);
   }
   else if (QStatusBar *sb = qobject_cast<QStatusBar*>(widget))
   {
@@ -965,8 +1024,8 @@ void Style::polish(QWidget *widget)
       if (qobject_cast<QMenu*>(widget))
       {
         /* On the one hand, RTL submenus aren't positioned correctly by Qt and, since
-            the RTL property isn't set yet, we should move them later. On the other hand,
-            menus should be moved to compensate for the offset created by their shadows. */
+           the RTL property isn't set yet, we should move them later. On the other hand,
+           menus should be moved to compensate for the offset created by their shadows. */
         widget->installEventFilter(this);
       }
 
@@ -986,7 +1045,7 @@ void Style::polish(QWidget *widget)
       { // see "Kvantum.cpp" -> setSurfaceFormat() for an explanation
         QPalette palette = widget->palette();
         palette.setColor(widget->backgroundRole(), QColor(Qt::transparent));
-        widget->setPalette(palette);
+        forcePalette(widget, palette);
       }
 #endif
 
@@ -997,15 +1056,14 @@ void Style::polish(QWidget *widget)
       {
         if (blurHelper_ == nullptr && tspec_now.popup_blurring)
         {
-          QList<qreal> tooltipS;
           if (tspec_now.tooltip_shadow_depth > 0)
           {
             const frame_spec fspec = getFrameSpec(QStringLiteral("ToolTip"));
             int thickness = qMax(qMax(fspec.top,fspec.bottom), qMax(fspec.left,fspec.right));
             thickness += tspec_now.tooltip_shadow_depth;
-            tooltipS = getShadow(QStringLiteral("ToolTip"), thickness);
+            getShadow(QStringLiteral("ToolTip"), thickness);
           }
-          blurHelper_ = new BlurHelper(this, menuShadow_, tooltipS,
+          blurHelper_ = new BlurHelper(this, menuShadow_, tooltipShadow_,
                                        tspec_.contrast, tspec_.intensity, tspec_.saturation);
         }
         /* blurHelper_ may exist because of blurring hard-coded translucency */
@@ -1062,8 +1120,10 @@ void Style::unpolish(QWidget *widget)
 {
   if (widget)
   {
+#if (QT_VERSION < QT_VERSION_CHECK(5,15,0))
     if (itsWindowManager_)
       itsWindowManager_->unregisterWidget(widget);
+#endif
 
     /*widget->setAttribute(Qt::WA_Hover, false);*/
 
@@ -1073,6 +1133,10 @@ void Style::unpolish(QWidget *widget)
       case Qt::Popup:
       case Qt::ToolTip:
       case Qt::Sheet: {
+#if (QT_VERSION >= QT_VERSION_CHECK(5,15,0))
+        if (itsWindowManager_)
+          itsWindowManager_->unregisterWidget(widget);
+#endif
         if (qobject_cast<QMenu*>(widget)
             || widget->inherits("QTipLabel")
             || qobject_cast<QLabel*>(widget))
@@ -1105,11 +1169,8 @@ void Style::unpolish(QWidget *widget)
         forcedTranslucency_.remove(widget);
         break;
       }
-      default: {
-        if (hspec_.scroll_jump_workaround)
-          widget->removeEventFilter(this);
+      default:
         break;
-      }
     }
 
     if (widget->inherits("KisAbstractSliderSpinBox")
@@ -1195,13 +1256,24 @@ void Style::unpolish(QApplication *app)
       w->setAttribute(Qt::WA_NoSystemBackground, false);
 #if (QT_VERSION < QT_VERSION_CHECK(5,13,1))
       w->setAttribute(Qt::WA_TranslucentBackground, false);
-
 #endif
     }
   }
   forcedTranslucency_.clear();
   translucentWidgets_.clear();
 
+  /* Reset all forced palettes.
+     This will be useful if the style changes from Kvantum in runtime. */
+  const auto widgets = app->allWidgets();
+  for (const auto &widget : widgets)
+  {
+    if (widget->property("_kv_fPalette").toBool())
+    {
+      widget->setPalette(QPalette());
+      widget->setProperty("_kv_fPalette", QVariant());
+    }
+  }
+
   if (app && itsShortcutHandler_)
     app->removeEventFilter(itsShortcutHandler_);
   QCommonStyle::unpolish(app);
