@@ -20,6 +20,7 @@
 #include <QSvgRenderer>
 #include <QPixmapCache>
 #include <QPainter>
+#include <QApplication>
 
 namespace Kvantum
 {
@@ -77,7 +78,11 @@ bool Style::renderElement(QPainter *painter,
   }
   if (!renderer) return false;
 
-  if (static_cast<qreal>(qRound(pixelRatio_)) != pixelRatio_)
+  qreal pixelRatio = qApp->devicePixelRatio();
+  if (painter->device())
+    pixelRatio = painter->device()->devicePixelRatioF();
+  pixelRatio = qMax(pixelRatio, static_cast<qreal>(1));
+  if (static_cast<qreal>(qRound(pixelRatio)) != pixelRatio)
   { // in this special case, we prevent one-pixel gaps between rectangles as far as possible
     painter->save();
     painter->setRenderHint(QPainter::SmoothPixmapTransform);
@@ -89,7 +94,7 @@ bool Style::renderElement(QPainter *painter,
     if (renderer->elementExists(_element+"-pattern"))
     {
       if (usePixmap)
-        drawSvgElement(renderer,painter,bounds,_element,pixelRatio_);
+        drawSvgElement(renderer,painter,bounds,_element,pixelRatio);
       else
         renderer->render(painter,_element,bounds);
     }
@@ -107,7 +112,7 @@ bool Style::renderElement(QPainter *painter,
     if (renderer->elementExists(_element+"-pattern"))
     {
       if (usePixmap)
-        drawSvgElement(renderer,painter,bounds,_element,pixelRatio_);
+        drawSvgElement(renderer,painter,bounds,_element,pixelRatio);
       else
         renderer->render(painter,_element,bounds);
       _element = _element+"-pattern";
@@ -134,12 +139,12 @@ bool Style::renderElement(QPainter *painter,
   else
   {
     if (usePixmap)
-      drawSvgElement(renderer,painter,bounds,_element,pixelRatio_);
+      drawSvgElement(renderer,painter,bounds,_element,pixelRatio);
     else
       renderer->render(painter,_element,bounds);
   }
 
-  if (static_cast<qreal>(qRound(pixelRatio_)) != pixelRatio_)
+  if (static_cast<qreal>(qRound(pixelRatio)) != pixelRatio)
     painter->restore();
 
   return true;
@@ -285,10 +290,6 @@ void Style::renderFrame(QPainter *painter,
                       && themeRndr_->elementExists(element0.replace(state,"-normal")))))))
   {
     drawExpanded = true; // can change below
-    fspec.left = fspec.leftExpanded;
-    fspec.right = fspec.rightExpanded;
-    fspec.top = fspec.topExpanded;
-    fspec.bottom = fspec.bottomExpanded;
   }
   if (/*!isLibreoffice_ &&*/ drawExpanded
       && (!fspec.isAttached || fspec.VPos == 2) // no vertical attachment
@@ -296,6 +297,12 @@ void Style::renderFrame(QPainter *painter,
           /* when there's enough space for a small frame expansion */
           || fspec.expansion < 2*qMin(h,w)))
   {
+    /* drawExpanded remains true */
+    fspec.left = fspec.leftExpanded;
+    fspec.right = fspec.rightExpanded;
+    fspec.top = fspec.topExpanded;
+    fspec.bottom = fspec.bottomExpanded;
+
     bool topElementMissing(!drawBorder);
     /* find the element that should be drawn (element1) */
     element0 = "border-"+realElement;
@@ -1062,6 +1069,11 @@ void Style::renderLabel(
           break;
       }
 
+      if (!txtCol.isValid())
+          txtCol = standardPalette().color(isInactive ? QPalette::Inactive
+                                                      : QPalette::Active,
+                                           textRole);
+
       if (lspec.hasShadow)
       {
         QColor shadowColor;
@@ -1097,24 +1109,21 @@ void Style::renderLabel(
         }
       }
 
-      if (txtCol.isValid())
+      painter->save();
+      if (hspec_.opaque_colors)
       {
-        painter->save();
-        if (hspec_.opaque_colors)
-        {
-          painter->setOpacity(txtCol.alphaF());
-          txtCol.setAlpha(255);
-        }
-        painter->setPen(txtCol);
-        painter->drawText(rtext,talign,text);
-        painter->restore();
-        if (lspec.boldFont)
-          painter->restore();
-        if (lspec.italicFont)
-          painter->restore();
-        painter->restore();
-        return;
+        painter->setOpacity(txtCol.alphaF());
+        txtCol.setAlpha(255);
       }
+      painter->setPen(txtCol);
+      painter->drawText(rtext,talign,text);
+      painter->restore();
+      if (lspec.boldFont)
+        painter->restore();
+      if (lspec.italicFont)
+        painter->restore();
+      painter->restore();
+      return;
     }
     /* if this is a dark-and-light theme, the disabled color may not be suitable */
     else if (state == 0
