@@ -36,6 +36,8 @@ QIcon Style::standardIcon(QStyle::StandardPixmap standardIcon,
   bool hdpi(false);
   if (qApp->testAttribute(Qt::AA_UseHighDpiPixmaps))
     hdpi = true;
+  qreal pixelRatio = qApp->devicePixelRatio();
+  pixelRatio = qMax(pixelRatio, static_cast<qreal>(1));
   const bool rtl(option != nullptr ? option->direction == Qt::RightToLeft
                                    : QApplication::layoutDirection() == Qt::RightToLeft);
   switch (standardIcon) {
@@ -43,9 +45,9 @@ QIcon Style::standardIcon(QStyle::StandardPixmap standardIcon,
       indicator_spec dspec = getIndicatorSpec(QStringLiteral("IndicatorArrow"));
       int s;
       if (hdpi)
-        s = qRound(pixelRatio_*pixelRatio_*static_cast<qreal>(dspec.size));
+        s = qRound(pixelRatio*pixelRatio*static_cast<qreal>(dspec.size));
       else
-        s = qRound(pixelRatio_*static_cast<qreal>(dspec.size));
+        s = qRound(pixelRatio*static_cast<qreal>(dspec.size));
       QPixmap pm(QSize(s,s));
       pm.fill(Qt::transparent);
 
@@ -86,9 +88,9 @@ QIcon Style::standardIcon(QStyle::StandardPixmap standardIcon,
       indicator_spec dspec = getIndicatorSpec(QStringLiteral("IndicatorArrow"));
       int s;
       if (hdpi)
-        s = qRound(pixelRatio_*pixelRatio_*static_cast<qreal>(dspec.size));
+        s = qRound(pixelRatio*pixelRatio*static_cast<qreal>(dspec.size));
       else
-        s = qRound(pixelRatio_*static_cast<qreal>(dspec.size));
+        s = qRound(pixelRatio*static_cast<qreal>(dspec.size));
       QPixmap pm(QSize(s,s));
       pm.fill(Qt::transparent);
 
@@ -159,9 +161,9 @@ QIcon Style::standardIcon(QStyle::StandardPixmap standardIcon,
     case SP_TitleBarMinButton : {
       int s;
       if (hdpi)
-        s = qRound(pixelMetric(PM_TitleBarButtonIconSize, option, widget)*pixelRatio_*pixelRatio_);
+        s = qRound(pixelMetric(PM_TitleBarButtonIconSize, option, widget)*pixelRatio*pixelRatio);
       else
-        s = qRound(pixelMetric(PM_TitleBarButtonIconSize, option, widget)*pixelRatio_);
+        s = qRound(pixelMetric(PM_TitleBarButtonIconSize, option, widget)*pixelRatio);
       QPixmap pm(QSize(s,s));
       pm.fill(Qt::transparent);
 
@@ -189,9 +191,9 @@ QIcon Style::standardIcon(QStyle::StandardPixmap standardIcon,
     case SP_TitleBarMaxButton : {
       int s;
       if (hdpi)
-        s = qRound(pixelMetric(PM_TitleBarButtonIconSize, option, widget)*pixelRatio_*pixelRatio_);
+        s = qRound(pixelMetric(PM_TitleBarButtonIconSize, option, widget)*pixelRatio*pixelRatio);
       else
-        s = qRound(pixelMetric(PM_TitleBarButtonIconSize, option, widget)*pixelRatio_);
+        s = qRound(pixelMetric(PM_TitleBarButtonIconSize, option, widget)*pixelRatio);
       QPixmap pm(QSize(s,s));
       pm.fill(Qt::transparent);
 
@@ -210,9 +212,9 @@ QIcon Style::standardIcon(QStyle::StandardPixmap standardIcon,
     case SP_TitleBarCloseButton : {
       int s;
       if (hdpi)
-        s = qRound(pixelMetric(PM_TitleBarButtonIconSize, option, widget)*pixelRatio_*pixelRatio_);
+        s = qRound(pixelMetric(PM_TitleBarButtonIconSize, option, widget)*pixelRatio*pixelRatio);
       else
-        s = qRound(pixelMetric(PM_TitleBarButtonIconSize, option, widget)*pixelRatio_);
+        s = qRound(pixelMetric(PM_TitleBarButtonIconSize, option, widget)*pixelRatio);
       QPixmap pm(QSize(s,s));
       pm.fill(Qt::transparent);
 
@@ -251,9 +253,9 @@ QIcon Style::standardIcon(QStyle::StandardPixmap standardIcon,
     case SP_TitleBarMenuButton : {
       int s;
       if (hdpi)
-        s = qRound(pixelMetric(PM_TitleBarButtonIconSize, option, widget)*pixelRatio_*pixelRatio_);
+        s = qRound(pixelMetric(PM_TitleBarButtonIconSize, option, widget)*pixelRatio*pixelRatio);
       else
-        s = qRound(pixelMetric(PM_TitleBarButtonIconSize, option, widget)*pixelRatio_);
+        s = qRound(pixelMetric(PM_TitleBarButtonIconSize, option, widget)*pixelRatio);
       QPixmap pm(QSize(s,s));
       pm.fill(Qt::transparent);
 
@@ -266,9 +268,9 @@ QIcon Style::standardIcon(QStyle::StandardPixmap standardIcon,
     case SP_TitleBarNormalButton : {
       int s;
       if (hdpi)
-        s = qRound(pixelMetric(PM_TitleBarButtonIconSize, option, widget)*pixelRatio_*pixelRatio_);
+        s = qRound(pixelMetric(PM_TitleBarButtonIconSize, option, widget)*pixelRatio*pixelRatio);
       else
-        s = qRound(pixelMetric(PM_TitleBarButtonIconSize, option, widget)*pixelRatio_);
+        s = qRound(pixelMetric(PM_TitleBarButtonIconSize, option, widget)*pixelRatio);
       QPixmap pm(QSize(s,s));
       pm.fill(Qt::transparent);
 
@@ -340,6 +342,11 @@ QIcon Style::standardIcon(QStyle::StandardPixmap standardIcon,
       if (!icn.isNull()) return icn;
       else break;
     }
+    case SP_DirOpenIcon : {
+      QIcon icn = QIcon::fromTheme(QLatin1String("folder-open"));
+      if (!icn.isNull()) return icn;
+      else break;
+    }
 
     /* arrow icons */
     case SP_ArrowUp : {
@@ -421,6 +428,7 @@ QIcon Style::standardIcon(QStyle::StandardPixmap standardIcon,
       if (!icn.isNull()) return icn;
       else break;
     }
+    case SP_CommandLink :
     case SP_ArrowForward : {
       if (rtl)
         return QCommonStyle::standardIcon(SP_ArrowLeft, option, widget);
@@ -481,9 +489,8 @@ QIcon Style::standardIcon(QStyle::StandardPixmap standardIcon,
       if (!icn.isNull()) return icn;
       else break;
     }
-    case SP_DirOpenIcon :
     case SP_DialogOpenButton : {
-      QIcon icn = QIcon::fromTheme(QLatin1String("folder-open"));
+      QIcon icn = QIcon::fromTheme(QLatin1String("document-open"));
       if (!icn.isNull()) return icn;
       else break;
     }
@@ -493,12 +500,20 @@ QIcon Style::standardIcon(QStyle::StandardPixmap standardIcon,
       if (!icn.isNull()) return icn;
       else break;
     }
+#if (QT_VERSION >= QT_VERSION_CHECK(5,14,0))
+    case SP_DialogYesToAllButton :
+#endif
     case SP_DialogYesButton :
     case SP_DialogOkButton : {
       QIcon icn = QIcon::fromTheme(QLatin1String("dialog-ok"));
       if (!icn.isNull()) return icn;
       else break;
     }
+#if (QT_VERSION >= QT_VERSION_CHECK(5,14,0))
+    case SP_DialogNoToAllButton :
+    case SP_DialogAbortButton :
+    case SP_DialogIgnoreButton :
+#endif
     case SP_DialogCancelButton :
     case SP_DialogNoButton : {
       QIcon icn = QIcon::fromTheme(QStringLiteral("dialog-cancel"),
@@ -526,6 +541,33 @@ QIcon Style::standardIcon(QStyle::StandardPixmap standardIcon,
       if (!icn.isNull()) return icn;
       else break;
     }
+    case SP_FileDialogToParent : {
+      QIcon icn = QIcon::fromTheme(QStringLiteral("go-up"));
+      if (!icn.isNull()) return icn;
+      else break;
+    }
+    case SP_FileDialogNewFolder : {
+      QIcon icn = QIcon::fromTheme(QStringLiteral("folder-new"));
+      if (!icn.isNull()) return icn;
+      else break;
+    }
+#if (QT_VERSION >= QT_VERSION_CHECK(5,14,0))
+    case SP_DialogSaveAllButton : {
+      QIcon icn = QIcon::fromTheme(QStringLiteral("document-save-all"));
+      if (!icn.isNull()) return icn;
+      else break;
+    }
+    case SP_DialogRetryButton : {
+      QIcon icn = QIcon::fromTheme(QStringLiteral("view-refresh"));
+      if (!icn.isNull()) return icn;
+      else break;
+    }
+    case SP_RestoreDefaultsButton : {
+      QIcon icn = QIcon::fromTheme(QStringLiteral("edit-undo"));
+      if (!icn.isNull()) return icn;
+      else break;
+    }
+#endif
     // these are for LXQt file dialog
     case SP_FileDialogListView : {
       QIcon icn = QIcon::fromTheme(QStringLiteral("view-list-text"));
