@@ -19,7 +19,7 @@
 #include <QFile>
 #include <QApplication>
 #include "ThemeConfig.h"
-#if defined Q_WS_X11 || defined Q_OS_LINUX || defined Q_OS_FREEBSD || defined Q_OS_HURD
+#if defined Q_WS_X11 || defined Q_OS_LINUX || defined Q_OS_FREEBSD || defined Q_OS_OPENBSD || defined Q_OS_NETBSD || defined Q_OS_HURD
 #include <QX11Info>
 #if (QT_VERSION >= QT_VERSION_CHECK(5,0,0))
 #include <X11/Xlib.h>
@@ -37,7 +37,7 @@ ThemeConfig::ThemeConfig(const QString& theme) :
 {
   /* For now, the lack of x11 means wayland.
      Later, a better method should be found. */
-#if defined Q_WS_X11 || defined Q_OS_LINUX || defined Q_OS_FREEBSD || defined Q_OS_HURD
+#if defined Q_WS_X11 || defined Q_OS_LINUX || defined Q_OS_FREEBSD || defined Q_OS_OPENBSD || defined Q_OS_NETBSD || defined Q_OS_HURD
 #if (QT_VERSION >= QT_VERSION_CHECK(5,2,0))
   isX11_ = QX11Info::isPlatformX11();
 #else
@@ -47,25 +47,30 @@ ThemeConfig::ThemeConfig(const QString& theme) :
   isX11_ = false;
 #endif
 
+  load(theme);
+
 #if (QT_VERSION >= QT_VERSION_CHECK(5,0,0))
   /* WARNING: Qt has a bug that causes drawing problems with a non-integer
      scale factor. Those problems can be seen with Fusion too but they become
      intense with an SVG window gradient and/or window translucency. As a
      workaround, we remove the window interior and translucency in this case. */
   const qreal dpr = qApp->devicePixelRatio();
-  nonIntegerScale = (dpr > 1.0 && static_cast<qreal>(qRound(dpr)) != dpr);
+  nonIntegerScale = (dpr > static_cast<qreal>(1) && static_cast<qreal>(qRound(dpr)) != dpr);
   if (nonIntegerScale)
   {
-    interior_spec r;
-    default_interior_spec(r);
-    r.hasInterior = false;
-    iSpecs_[KSL("WindowTranslucent")] = iSpecs_[KSL("Window")] = iSpecs_[KSL("Dialog")] = r;
+    nonIntegerScale = !getValue(KSL("Hacks"),KSL("noninteger_translucency")).toBool();
+    if (nonIntegerScale)
+    {
+      interior_spec r;
+      default_interior_spec(r);
+      r.hasInterior = false;
+      iSpecs_[KSL("WindowTranslucent")] = iSpecs_[KSL("Window")] = iSpecs_[KSL("Dialog")] = r;
+    }
   }
 #else
   nonIntegerScale = false;
 #endif
 
-  load(theme);
   default_theme_spec(compositeSpecs_);
 }
 
@@ -503,6 +508,15 @@ label_spec ThemeConfig::getLabelSpec(const QString &elementName)
       r.top = qMax(0,r.top-1);
       r.bottom = qMax(0,r.bottom-1);
     }
+    else if(name == "ItemView")
+    {
+      /* we should be cautious about view items because
+         we don't draw their texts (see Kvantum.cpp -> CE_ItemViewItem) */
+      r.left = qMin(r.left,4);
+      r.right = qMin(r.right,4);
+      r.top = qMin(r.top,4);
+      r.bottom = qMin(r.bottom,4);
+    }
   }
 
   v = getValue(name,KSL("text.iconspacing"), i);
@@ -570,8 +584,7 @@ theme_spec ThemeConfig::getCompositeSpec()
 {
   bool compositing(false);
 
-#if defined Q_WS_X11 || defined Q_OS_LINUX || defined Q_OS_FREEBSD || defined Q_OS_HURD
-  /* set to false if no compositing manager is running */
+#if defined Q_WS_X11 || defined Q_OS_LINUX || defined Q_OS_FREEBSD || defined Q_OS_OPENBSD || defined Q_OS_NETBSD || defined Q_OS_HURD
 #if (QT_VERSION >= QT_VERSION_CHECK(5,2,0))
   if (isX11_)
   {
@@ -585,8 +598,6 @@ theme_spec ThemeConfig::getCompositeSpec()
   if (QX11Info::isCompositingManagerRunning())
     compositing = true;
 #endif
-/*#elif (QT_VERSION >= QT_VERSION_CHECK(5,11,0))
-  compositing = true; // presuppose a compositor without Linux and X11*/
 #endif
 
   /* no blurring or window translucency without compositing */
@@ -724,6 +735,11 @@ theme_spec ThemeConfig::getThemeSpec()
       r.x11drag = WindowManager::toDrag(v.toString());
   }
 
+#if (QT_VERSION >= QT_VERSION_CHECK(5,15,0))
+  v = getValue(KSL("General"),KSL("drag_from_buttons"));
+  r.drag_from_buttons = v.toBool();
+#endif
+
   v = getValue(KSL("General"),KSL("respect_DE"));
   if (v.isValid()) // true by default
     r.respect_DE = v.toBool();
@@ -1139,12 +1155,14 @@ hacks_spec ThemeConfig::getHacksSpec() const
 #endif
 
 #if (QT_VERSION >= QT_VERSION_CHECK(5,14,0))
-  /* a workaround for a nasty bug about text translucency in Qt 5.14.0 */
+  /* A workaround for a nasty bug about text translucency in Qt 5.14.0.
+     The bug was fixed in Qt 5.14.1 but better safe than sorry. */
   r.opaque_colors = true;
 #else
-  v = getValue(KSL("Hacks"),KSL("opaque_colors"));
+  /*v = getValue(KSL("Hacks"),KSL("opaque_colors"));
   if (v.isValid())
-    r.opaque_colors = v.toBool();
+    r.opaque_colors = v.toBool();*/
+  r.opaque_colors = false;
 #endif
 
   v = getValue(KSL("Hacks"),KSL("transparent_ktitle_label"));
@@ -1154,7 +1172,8 @@ hacks_spec ThemeConfig::getHacksSpec() const
   r.transparent_menutitle = v.toBool();
 
   v = getValue(KSL("Hacks"),KSL("kcapacitybar_as_progressbar"));
-  r.kcapacitybar_as_progressbar = v.toBool();
+  if (v.isValid()) // true by default
+    r.kcapacitybar_as_progressbar = v.toBool();
 
   v = getValue(KSL("Hacks"),KSL("respect_darkness"));
   r.respect_darkness = v.toBool();
@@ -1191,11 +1210,14 @@ hacks_spec ThemeConfig::getHacksSpec() const
   v = getValue(KSL("Hacks"),KSL("middle_click_scroll"));
   r.middle_click_scroll = v.toBool();
 
+  v = getValue(KSL("Hacks"),KSL("centered_forms"));
+  r.centered_forms = v.toBool();
+
   v = getValue(KSL("Hacks"),KSL("kinetic_scrolling"));
   r.kinetic_scrolling = v.toBool();
 
-  v = getValue(KSL("Hacks"),KSL("scroll_jump_workaround"));
-  r.scroll_jump_workaround = v.toBool();
+  v = getValue(KSL("Hacks"),KSL("noninteger_translucency"));
+  r.noninteger_translucency = v.toBool();
 
   return r;
 }
