@@ -20,8 +20,12 @@
 
 #include <QStringList>
 #if (QT_VERSION >= QT_VERSION_CHECK(5,0,0))
+#if (QT_VERSION >= QT_VERSION_CHECK(5,15,0))
 #include "drag/windowmanager.h"
 #else
+#include "drag/windowmanager-old.h"
+#endif
+#else
 #include "qt4/windowmanager4.h"
 #endif
 
@@ -33,8 +37,10 @@ typedef struct {
   /* running on X11? (only used internally) */
   bool isX11;
   /* draggable from menubar, primary toolbar
-     or anywhere possible (under x11)? */
+     or anywhere possible (under X11 and Wayland)? */
   WindowManager::Drag x11drag;
+  /* also, drag from buttons? */
+  bool drag_from_buttons;
   /* should some settings of the current DE be respected? */
   bool respect_DE;
   /* show mnemonics only if Alt is pressed? */
@@ -267,7 +273,8 @@ typedef struct {
   /* blur the region behind a window background that is
      explicitly made translucent by its app? */
   bool blur_translucent;
-  /* should all texts have opaque colors? */
+  /* should all texts have opaque colors?
+     (used internally as a workaround) */
   bool opaque_colors;
   /* transparent background for the label of KTitleWidget
      (nice when the window bg has a gradient) */
@@ -302,10 +309,13 @@ typedef struct {
   /* should the scroll jump be done by middle clicking?
      (By default, it's done by left clicking.) */
   bool middle_click_scroll;
+  /* should forms be drawn centered? */
+  bool centered_forms;
   /* enable kinetic scrolling? */
   bool kinetic_scrolling;
-  /* workaround for annoying Qt5 scroll jumps? */
-  bool scroll_jump_workaround;
+  /* enable window translucency and gradient with
+     non-integer scale factors? (disabled because of Qt's bugs) */
+  bool noninteger_translucency;
 } hacks_spec;
 
 /* Generic information about a frame */
@@ -456,6 +466,7 @@ static inline void default_size_spec(size_spec &sspec) {
 static inline void default_theme_spec(theme_spec &tspec) {
   tspec.isX11 = false;
   tspec.x11drag = WindowManager::DRAG_ALL;
+  tspec.drag_from_buttons = false;
   tspec.respect_DE = true;
   tspec.alt_mnemonic = true;
   tspec.click_behavior = 0;
@@ -555,7 +566,7 @@ static inline void default_hacks_spec(hacks_spec &hspec) {
   hspec.opaque_colors = false;
   hspec.transparent_ktitle_label = false;
   hspec.transparent_menutitle = false;
-  hspec.kcapacitybar_as_progressbar = false;
+  hspec.kcapacitybar_as_progressbar = true;
   hspec.respect_darkness = false;
   hspec.forceSizeGrip = false;
   hspec.tint_on_mouseover = 0;
@@ -567,8 +578,9 @@ static inline void default_hacks_spec(hacks_spec &hspec) {
   hspec.iconless_menu = false;
   hspec.single_top_toolbar = false;
   hspec.middle_click_scroll = false;
+  hspec.centered_forms = false;
   hspec.kinetic_scrolling = false;
-  hspec.scroll_jump_workaround = false;
+  hspec.noninteger_translucency = false;
 }
 }
 
